[Libreoffice-commits] core.git: desktop/scripts svx/source

2018-06-25 Thread Thomas Klausner
 desktop/scripts/soffice.sh  |7 ++-
 desktop/scripts/unopkg.sh   |6 +-
 svx/source/gengal/gengal.sh |6 +-
 3 files changed, 16 insertions(+), 3 deletions(-)

New commits:
commit 8db53bfd74e48f60e3002b2ae5f7f13c9387725a
Author: Thomas Klausner 
Date:   Mon Jun 25 23:42:44 2018 +0200

Fix "javaPathHelper: not found" errors during startup.

javaPathHelper is a tool from OpenBSD ports, so there is no point
looking for it on other operating systems.

Change-Id: I763d717fdf7172b412d527fcd88347b2e54a8fe9

diff --git a/desktop/scripts/soffice.sh b/desktop/scripts/soffice.sh
index 5c76b6e2211d..df295cb76250 100755
--- a/desktop/scripts/soffice.sh
+++ b/desktop/scripts/soffice.sh
@@ -141,7 +141,7 @@ if echo "$checks" | grep -q "cc" ; then
 fi
 
 case "$(uname -s)" in
-NetBSD|OpenBSD|DragonFly)
+OpenBSD)
 # this is a temporary hack until we can live with the default search paths
 LD_LIBRARY_PATH="$sd_prog${LD_LIBRARY_PATH:+:$LD_LIBRARY_PATH}"
 JAVA_HOME=$(javaPathHelper -h libreoffice-java 2> /dev/null)
@@ -150,6 +150,11 @@ NetBSD|OpenBSD|DragonFly)
 export JAVA_HOME
 fi
 ;;
+NetBSD|DragonFly)
+# this is a temporary hack until we can live with the default search paths
+LD_LIBRARY_PATH="$sd_prog${LD_LIBRARY_PATH:+:$LD_LIBRARY_PATH}"
+export LD_LIBRARY_PATH
+;;
 AIX)
 LIBPATH="$sd_prog${LIBPATH:+:$LIBPATH}"
 export LIBPATH
diff --git a/desktop/scripts/unopkg.sh b/desktop/scripts/unopkg.sh
index 83068d29d35e..3adf69c2e56e 100755
--- a/desktop/scripts/unopkg.sh
+++ b/desktop/scripts/unopkg.sh
@@ -37,7 +37,7 @@ cd "$sd_cwd" || exit $?
 
 # this is a temporary hack until we can live with the default search paths
 case "$(uname -s)" in
-NetBSD|OpenBSD|FreeBSD|DragonFly)
+OpenBSD)
 LD_LIBRARY_PATH="$sd_prog${LD_LIBRARY_PATH:+:${LD_LIBRARY_PATH}}"
 JAVA_HOME=$(javaPathHelper -h libreoffice-java 2> /dev/null)
 export LD_LIBRARY_PATH
@@ -45,6 +45,10 @@ NetBSD|OpenBSD|FreeBSD|DragonFly)
 export JAVA_HOME
 fi
 ;;
+NetBSD|FreeBSD|DragonFly)
+LD_LIBRARY_PATH="$sd_prog${LD_LIBRARY_PATH:+:${LD_LIBRARY_PATH}}"
+export LD_LIBRARY_PATH
+;;
 AIX)
 LIBPATH="$sd_prog${LIBPATH:+:${LIBPATH}}"
 export LIBPATH
diff --git a/svx/source/gengal/gengal.sh b/svx/source/gengal/gengal.sh
index b4d10458650a..3970ab1fa9c8 100755
--- a/svx/source/gengal/gengal.sh
+++ b/svx/source/gengal/gengal.sh
@@ -35,7 +35,7 @@ cd "$sd_cwd"
 
 # this is a temporary hack until we can live with the default search paths
 case "$(uname -s)" in
-NetBSD|OpenBSD|FreeBSD|DragonFly)
+OpenBSD)
 LD_LIBRARY_PATH=$sd_prog${LD_LIBRARY_PATH:+:${LD_LIBRARY_PATH}}
 JAVA_HOME=$(javaPathHelper -h libreoffice-java 2> /dev/null)
 export LD_LIBRARY_PATH
@@ -43,6 +43,10 @@ NetBSD|OpenBSD|FreeBSD|DragonFly)
 export JAVA_HOME
 fi
 ;;
+NetBSD|FreeBSD|DragonFly)
+LD_LIBRARY_PATH=$sd_prog${LD_LIBRARY_PATH:+:${LD_LIBRARY_PATH}}
+export LD_LIBRARY_PATH
+;;
 AIX)
 LIBPATH=$sd_prog${LIBPATH:+:${LIBPATH}}
 export LIBPATH
___
Libreoffice-commits mailing list
libreoffice-comm...@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] core.git: sw/source

2015-08-09 Thread Thomas Klausner
 sw/source/filter/ww8/ww8toolbar.cxx |6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

New commits:
commit 938a1b00332090e68cca44c99eb6f4adeedc1f00
Author: Thomas Klausner w...@netbsd.org
Date:   Sun Aug 9 20:28:24 2015 +0200

Fix some typos in strings.

Change-Id: I7fb077c08dbfa3fe3f03941c7567dc65630cf266

diff --git a/sw/source/filter/ww8/ww8toolbar.cxx 
b/sw/source/filter/ww8/ww8toolbar.cxx
index 429d3b5..6460cc6 100644
--- a/sw/source/filter/ww8/ww8toolbar.cxx
+++ b/sw/source/filter/ww8/ww8toolbar.cxx
@@ -214,7 +214,7 @@ void SwCTBWrapper::Print( FILE* fp )
 
 for ( std::vector Customization ::iterator it = rCustomizations.begin(); 
it != rCustomizations.end(); ++it, ++index )
 {
-indent_printf(fp,  Dumping custimization [%d]\n, static_cast int ( 
index ));
+indent_printf(fp,  Dumping customization [%d]\n, static_cast int ( 
index ));
 Indent c;
 it-Print(fp);
 }
@@ -258,7 +258,7 @@ Customization::~Customization()
 
 bool Customization::Read( SvStream rS)
 {
-SAL_INFO(sw.ww8,Custimization::Read() stream pos 0x  std::hex  
rS.Tell() );
+SAL_INFO(sw.ww8,Customization::Read() stream pos 0x  std::hex  
rS.Tell() );
 nOffSet = rS.Tell();
 rS.ReadInt32( tbidForTBD ).ReadUInt16( reserved1 ).ReadUInt16( ctbds );
 if ( tbidForTBD )
@@ -273,7 +273,7 @@ bool Customization::Read( SvStream rS)
 if (!aTBDelta.Read( rS ) )
 return false;
 customizationDataTBDelta.push_back( aTBDelta );
-// Only set the drop down for menu's associated with standard 
toolbar
+// Only set the drop down for menus associated with standard 
toolbar
 if ( aTBDelta.ControlDropsToolBar()  tbidForTBD == 0x25 )
 pWrapper-InsertDropIndex( aTBDelta.CustomizationIndex() );
 }
___
Libreoffice-commits mailing list
libreoffice-comm...@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] core.git: sw/source

2015-08-09 Thread Thomas Klausner
 sw/source/filter/ww8/ww8par6.cxx |  504 +++
 1 file changed, 250 insertions(+), 254 deletions(-)

New commits:
commit 78a11f79d8eb5cd1d2b18c288852dec7e3d57a21
Author: Thomas Klausner w...@netbsd.org
Date:   Mon Aug 10 07:57:07 2015 +0200

Translate German comments to English, part 1.

Only about 60% done, but this file is huge, so do a checkpoint commit.

Change-Id: Ic2ea67c894c525d89baf5287c8d009727911e816

diff --git a/sw/source/filter/ww8/ww8par6.cxx b/sw/source/filter/ww8/ww8par6.cxx
index 9d3fd16..0e587a0 100644
--- a/sw/source/filter/ww8/ww8par6.cxx
+++ b/sw/source/filter/ww8/ww8par6.cxx
@@ -105,10 +105,10 @@ using namespace sw::types;
 using namespace ::com::sun::star;
 using namespace nsHdFtFlags;
 
-//  diverses
+//  various
 
-#define MM_250 1417 // WW-Default fuer Hor. Seitenraender: 2.5 cm
-#define MM_200 1134 // WW-Default fuer u.Seitenrand: 2.0 cm
+#define MM_250 1417 // WW default for horizontal borders: 2.5 cm
+#define MM_200 1134 // WW default for lower border: 2.0 cm
 
 
 static sal_uInt8 lcl_ReadBorders(bool bVer67, WW8_BRCVer9* brc, 
WW8PLCFx_Cp_FKP* pPap,
@@ -134,26 +134,26 @@ inline sal_uInt32 MSRoundTweak(sal_uInt32 x)
 return x;
 }
 
-// Seiten - Attribute, die nicht ueber die Attribut-Verwaltung, sondern
-//  ueber ...-HasSprm abgearbeitet werden
-//  ( ausser OLST, dass weiterhin ein normales Attribut ist )
+// page attribute which are not handled via the attribute management but
+// using ...-HasSprm
+// (except OLST which stays a normal attribute)
 static short ReadSprm( const WW8PLCFx_SEPX* pSep, sal_uInt16 nId, short 
nDefaultVal )
 {
-const sal_uInt8* pS = pSep-HasSprm( nId );  // sprm da ?
+const sal_uInt8* pS = pSep-HasSprm( nId );  // sprm here?
 short nVal = ( pS ) ? SVBT16ToShort( pS ) : nDefaultVal;
 return nVal;
 }
 
 static sal_uInt16 ReadUSprm( const WW8PLCFx_SEPX* pSep, sal_uInt16 nId, short 
nDefaultVal )
 {
-const sal_uInt8* pS = pSep-HasSprm( nId );  // sprm da ?
+const sal_uInt8* pS = pSep-HasSprm( nId );  // sprm here?
 sal_uInt16 nVal = ( pS ) ? SVBT16ToShort( pS ) : nDefaultVal;
 return nVal;
 }
 
 static sal_uInt8 ReadBSprm( const WW8PLCFx_SEPX* pSep, sal_uInt16 nId, 
sal_uInt8 nDefaultVal )
 {
-const sal_uInt8* pS = pSep-HasSprm( nId );  // sprm da ?
+const sal_uInt8* pS = pSep-HasSprm( nId );  // sprm here?
 sal_uInt8 nVal = pS ? *pS : nDefaultVal;
 return nVal;
 }
@@ -414,10 +414,10 @@ void wwSectionManager::SetLeftRight(wwSection rSection)
 void wwSectionManager::SetPage(SwPageDesc rInPageDesc, SwFrameFormat rFormat,
 const wwSection rSection, bool bIgnoreCols)
 {
-// 1. Orientierung
+// 1. orientation
 rInPageDesc.SetLandscape(rSection.IsLandScape());
 
-// 2. Papiergroesse
+// 2. paper size
 SwFormatFrmSize aSz( rFormat.GetFrmSize() );
 aSz.SetWidth(rSection.GetPageWidth());
 
aSz.SetHeight(SvxPaperInfo::GetSloppyPaperDimension(rSection.GetPageHeight()));
@@ -539,7 +539,7 @@ void wwSectionManager::GetPageULData(const wwSection 
rSection,
 
 if( rData.bHasHeader )
 {
-rData.nSwUp  = nWWHTop; // Header - umrechnen
+rData.nSwUp  = nWWHTop; // Header - convert
 // #i19922# - correction:
 // consider that nWWUp can be negative, compare only if it's positive
 if ( nWWUp  0 
@@ -553,7 +553,7 @@ void wwSectionManager::GetPageULData(const wwSection 
rSection,
 if (rData.nSwHLo  sal::static_int_cast sal_uInt32 (cMinHdFtHeight))
 rData.nSwHLo = sal::static_int_cast sal_uInt32 (cMinHdFtHeight);
 }
-else // kein Header - Up einfach uebernehmen
+else // no header - just use Up as-is
 rData.nSwUp = std::abs(nWWUp);
 
 rData.bHasFooter = (rSection.maSep.grpfIhdt 
@@ -561,7 +561,7 @@ void wwSectionManager::GetPageULData(const wwSection 
rSection,
 
 if( rData.bHasFooter )
 {
-rData.nSwLo = nWWFBot;  // Footer - Umrechnen
+rData.nSwLo = nWWFBot;  // footer - convert
 // #i19922# - correction: consider that nWWLo can be negative, 
compare only if it's positive
 if ( nWWLo  0 
  static_castsal_uInt32(abs(nWWLo)) = nWWFBot )
@@ -574,16 +574,16 @@ void wwSectionManager::GetPageULData(const wwSection 
rSection,
 if (rData.nSwFUp  sal::static_int_cast sal_uInt32 (cMinHdFtHeight))
 rData.nSwFUp = sal::static_int_cast sal_uInt32 (cMinHdFtHeight);
 }
-else // kein Footer - Lo einfach uebernehmen
+else // no footer - just use Lo as-is
 rData.nSwLo = std::abs(nWWLo);
 }
 
 void wwSectionManager::SetPageULSpaceItems(SwFrameFormat rFormat,
 wwSectionManager::wwULSpaceData rData, const wwSection rSection)
 {
-if (rData.bHasHeader)   // ... und Header-Lower setzen

[Libreoffice-commits] core.git: sw/source

2015-08-08 Thread Thomas Klausner
 sw/source/filter/ww8/ww8scan.cxx |8 
 1 file changed, 4 insertions(+), 4 deletions(-)

New commits:
commit 2981bcf7e34d9f4c9d1e821045f3f22ddb318339
Author: Thomas Klausner w...@netbsd.org
Date:   Sat Aug 8 09:43:02 2015 +0200

Translate two assertions to English, adapt two others for consistency.

diff --git a/sw/source/filter/ww8/ww8scan.cxx b/sw/source/filter/ww8/ww8scan.cxx
index 6c1c600..04e07a1 100644
--- a/sw/source/filter/ww8/ww8scan.cxx
+++ b/sw/source/filter/ww8/ww8scan.cxx
@@ -1716,7 +1716,7 @@ WW8ScannerBase::WW8ScannerBase( SvStream* pSt, SvStream* 
pTableSt,
 
 break;
 default:
-OSL_ENSURE( false, Es wurde vergessen, nVersion zu kodieren! );
+OSL_ENSURE( false, nVersion not implemented! );
 break;
 }
 
@@ -2842,7 +2842,7 @@ bool WW8PLCFx_Fc_FKP::NewFkp()
 break;
 default:
 // program error!
-OSL_ENSURE( false, Someone forgot to encode nVersion! );
+OSL_ENSURE( false, nVersion not implemented! );
 return false;
 }
 
@@ -5341,7 +5341,7 @@ WW8Fib::WW8Fib(SvStream rSt, sal_uInt8 nWantedVersion, 
sal_uInt32 nOffset)
 nFibMin = 0;// programm error!
 nFibMax = 0;
 nFib= 1;
-OSL_ENSURE( false, It was forgotten to encode nVersion! );
+OSL_ENSURE( false, nVersion not implemented! );
 break;
 }
 if ( (nFib  nFibMin) || (nFib  nFibMax) )
@@ -6402,7 +6402,7 @@ WW8Fonts::WW8Fonts( SvStream rSt, WW8Fib rFib )
 // always in ANSI, even if eStructCharSet == CHARSET_MAC !!
 if( rFib.lcbSttbfffn = 2 )
 {
-OSL_ENSURE( false, Fonttabelle kaputt! (rFib.lcbSttbfffn  2) );
+OSL_ENSURE( false, font table is broken! (rFib.lcbSttbfffn  2) );
 return;
 }
 
___
Libreoffice-commits mailing list
libreoffice-comm...@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] core.git: configure.ac

2015-08-08 Thread Thomas Klausner
 configure.ac |2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

New commits:
commit 29690bee381a9075ffa90a826a2b5a5a94a6673a
Author: Thomas Klausner w...@netbsd.org
Date:   Sat Aug 8 10:33:41 2015 +0200

When looking for tar, accept 'bsdtar'.

libarchive installs it under that name at least on FreeBSD, NetBSD,
and OpenBSD.

Change-Id: I7c4ce8f2dcf59f6d2b23266f450a88f3f2217e4e

diff --git a/configure.ac b/configure.ac
index 0d45455..7b0f031 100644
--- a/configure.ac
+++ b/configure.ac
@@ -2465,7 +2465,7 @@ fi
 AC_SUBST(BASH)
 
 AC_MSG_CHECKING([for GNU or BSD tar])
-for a in $GNUTAR gtar gnutar tar /usr/sfw/bin/gtar; do
+for a in $GNUTAR gtar gnutar bsdtar tar /usr/sfw/bin/gtar; do
 $a --version 2 /dev/null | egrep GNU|bsdtar  21  /dev/null
 if test $? -eq 0;  then
 GNUTAR=$a
___
Libreoffice-commits mailing list
libreoffice-comm...@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] core.git: external/glm

2015-08-08 Thread Thomas Klausner
 external/glm/UnpackedTarball_glm.mk |2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

New commits:
commit 05925ef8a49f3ba302140bd37ba9c4848598638d
Author: Thomas Klausner w...@netbsd.org
Date:   Sat Aug 8 17:59:09 2015 +0200

Do not add --binary to patch flags unconditionally.

It is only needed for Cygwin, and some patch(1) don't support it,
like NetBSD's.

Solution suggested by vmiklos on irc.

Change-Id: I65a3a82e755167828658218c7d73c4f2294e587f

diff --git a/external/glm/UnpackedTarball_glm.mk 
b/external/glm/UnpackedTarball_glm.mk
index 82f4a2c..f593254 100644
--- a/external/glm/UnpackedTarball_glm.mk
+++ b/external/glm/UnpackedTarball_glm.mk
@@ -11,7 +11,7 @@ $(eval $(call gb_UnpackedTarball_UnpackedTarball,glm))
 
 $(eval $(call gb_UnpackedTarball_set_tarball,glm,$(GLM_TARBALL)))
 
-$(eval $(call gb_UnpackedTarball_set_patchflags,glm,--binary))
+$(eval $(call gb_UnpackedTarball_set_patchflags,glm,$(if $(filter 
MSC,$(COM)),--binary)))
 
 $(eval $(call gb_UnpackedTarball_set_patchlevel,glm,1))
 
___
Libreoffice-commits mailing list
libreoffice-comm...@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] core.git: sw/source

2015-08-07 Thread Thomas Klausner
 sw/source/filter/ww8/docxattributeoutput.hxx |4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

New commits:
commit d026cad64c72eacf7bff9bbd7e3bb5b1a56f8479
Author: Thomas Klausner w...@netbsd.org
Date:   Fri Aug 7 22:03:53 2015 +0200

Fix typos in comments.

Change-Id: I5b97d12171020dab1379d4f7e78cab7de4a779df

diff --git a/sw/source/filter/ww8/docxattributeoutput.hxx 
b/sw/source/filter/ww8/docxattributeoutput.hxx
index a2e2599..54d3f11 100644
--- a/sw/source/filter/ww8/docxattributeoutput.hxx
+++ b/sw/source/filter/ww8/docxattributeoutput.hxx
@@ -937,10 +937,10 @@ public:
 virtual DocxExport GetExport() SAL_OVERRIDE;
 const DocxExport GetExport() const { return const_cast 
DocxAttributeOutput* ( this )-GetExport(); }
 
-/// For eg. the output of the styles, we need to switch the serializer to 
an other one.
+/// For e.g. the output of the styles, we need to switch the serializer to 
another one.
 void SetSerializer( ::sax_fastparser::FSHelperPtr pSerializer );
 
-/// Occasionnaly need to use this serializer from the outside
+/// Occasionally need to use this serializer from the outside
 ::sax_fastparser::FSHelperPtr GetSerializer( ) { return m_pSerializer; }
 
 /// Do we have any footnotes?
___
Libreoffice-commits mailing list
libreoffice-comm...@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] core.git: sw/source

2015-08-07 Thread Thomas Klausner
 sw/source/filter/ww8/ww8scan.hxx |  241 +++
 1 file changed, 120 insertions(+), 121 deletions(-)

New commits:
commit 6f98a0ab51cc5c860576b4ad44478b438cc5a5eb
Author: Thomas Klausner w...@netbsd.org
Date:   Fri Aug 7 18:24:45 2015 +0200

Translate remaining German comments to English.

Change-Id: I0b6b60bd4fa921993388340b8c16c533ba9f257f

diff --git a/sw/source/filter/ww8/ww8scan.hxx b/sw/source/filter/ww8/ww8scan.hxx
index cc2d0f6..cd101bd 100644
--- a/sw/source/filter/ww8/ww8scan.hxx
+++ b/sw/source/filter/ww8/ww8scan.hxx
@@ -173,21 +173,21 @@ void WW8ReadSTTBF(bool bVer8, SvStream rStrm, sal_uInt32 
nStart, sal_Int32 nLen
 
 struct WW8FieldDesc
 {
-long nLen;  /// Gesamtlaenge ( zum Text ueberlesen )
-WW8_CP nSCode;  /// Anfang Befehlscode
-WW8_CP nLCode;  /// Laenge
-WW8_CP nSRes;   /// Anfang Ergebnis
-WW8_CP nLRes;   /// Laenge ( == 0, falls kein Ergebnis )
-sal_uInt16 nId; /// WW-Id fuer Felder
-sal_uInt8 nOpt;  /// WW-Flags ( z.B.: vom User geaendert )
-bool bCodeNest:1;   /// Befehl rekursiv verwendet
-bool bResNest:1;/// Befehl in Resultat eingefuegt
+long nLen;  /// total length (to skip over text)
+WW8_CP nSCode;  /// start of instructions code
+WW8_CP nLCode;  /// length
+WW8_CP nSRes;   /// start of result
+WW8_CP nLRes;   /// length ( == 0, if no result )
+sal_uInt16 nId; /// WW-id for fields
+sal_uInt8 nOpt;  /// WW-Flags ( e.g.: changed by user )
+bool bCodeNest:1;   /// instruction used recursively
+bool bResNest:1;/// instruction inserted into result
 };
 
 struct WW8PLCFxSave1
 {
 sal_uLong nPLCFxPos;
-sal_uLong nPLCFxPos2;   /// fuer PLCF_Cp_Fkp: PieceIter-Pos
+sal_uLong nPLCFxPos2;   /// for PLCF_Cp_Fkp: PieceIter-Pos
 long nPLCFxMemOfs;
 WW8_CP nStartCp;/// for cp based iterator like PAP and CHP
 long nCpOfs;
@@ -198,16 +198,16 @@ struct WW8PLCFxSave1
 };
 
 /**
-u.a. fuer Felder, also genausoviele Attr wie Positionen,
-falls Ctor-Param bNoEnd = false
+among others for fields, that is, the same number of attr as positions,
+if Ctor-Param bNoEnd = false
 */
-class WW8PLCFspecial// Iterator fuer PLCFs
+class WW8PLCFspecial// iterator for PLCFs
 {
 private:
-sal_Int32* pPLCF_PosArray;  /// Pointer auf Pos-Array und auf ganze 
Struktur
-sal_uInt8*  pPLCF_Contents;  /// Pointer auf Inhalts-Array-Teil des 
Pos-Array
-long nIMax; /// Anzahl der Elemente
-long nIdx;  /// Merker, wo wir gerade sind
+sal_Int32* pPLCF_PosArray;  /// pointer to Pos-array and to the whole 
structure
+sal_uInt8*  pPLCF_Contents;  /// pointer to content-array-part of 
Pos-array
+long nIMax; /// number of elements
+long nIdx;  /// marker where we currently are
 sal_uInt32 nStru;
 
 public:
@@ -217,8 +217,8 @@ public:
 long GetIdx() const { return nIdx; }
 void SetIdx( long nI ) { nIdx = nI; }
 long GetIMax() const { return nIMax; }
-bool SeekPos(long nPos);// geht ueber FC- bzw. CP-Wert
-// bzw. naechste groesseren Wert
+bool SeekPos(long nPos);// walks over FC- or CP-value
+// resp. next biggest value
 bool SeekPosExact(long nPos);
 sal_Int32 Where() const
 { return ( nIdx = nIMax ) ? SAL_MAX_INT32 : pPLCF_PosArray[nIdx]; }
@@ -271,21 +271,21 @@ private:
 WW8SprmIter operator=(const WW8SprmIter) SAL_DELETED_FUNCTION;
 };
 
-/* u.a. fuer FKPs auf normale Attr., also ein Attr weniger als Positionen */
-class WW8PLCF   // Iterator fuer PLCFs
+/* among others for FKPs to normal attr., i.e. one less attr than positions */
+class WW8PLCF   // Iterator for PLCFs
 {
 private:
-WW8_CP* pPLCF_PosArray; // Pointer auf Pos-Array und auf ganze Struktur
-sal_uInt8* pPLCF_Contents;   // Pointer auf Inhalts-Array-Teil des 
Pos-Array
-sal_Int32 nIMax;// Anzahl der Elemente
+WW8_CP* pPLCF_PosArray; // pointer to Pos-array and the whole structure
+sal_uInt8* pPLCF_Contents;   // pointer to content-array-part of Pos-array
+sal_Int32 nIMax;// number of elements
 sal_Int32 nIdx;
 int nStru;
 
 void ReadPLCF(SvStream rSt, WW8_FC nFilePos, sal_uInt32 nPLCF);
 
 /*
-Falls im Dok ein PLC fehlt und die FKPs solo dastehen,
-machen wir uns hiermit einen PLC:
+If a PLC is missing in the doc and the FKPs stand alone,
+we create a PLC with this:
 */
 void GeneratePLCF(SvStream rSt, sal_Int32 nPN, sal_Int32 ncpN);
 
@@ -296,7 +296,7 @@ public:
 WW8_CP nStartPos = -1);
 
 /*
-folgender Ctor generiert ggfs. einen PLC

[Libreoffice-commits] core.git: sw/source

2015-08-07 Thread Thomas Klausner
 sw/source/filter/ww8/ww8par.hxx |  202 +++-
 1 file changed, 100 insertions(+), 102 deletions(-)

New commits:
commit da4bd92d474455c6ef88ec2190b6c305ee3740ba
Author: Thomas Klausner w...@netbsd.org
Date:   Fri Aug 7 18:43:22 2015 +0200

Translate remaining German comments to English.

Change-Id: If0bd1d61578176ae82630ed35309c6fe0e79a4d1

diff --git a/sw/source/filter/ww8/ww8par.hxx b/sw/source/filter/ww8/ww8par.hxx
index e2bd354..e11ef0f 100644
--- a/sw/source/filter/ww8/ww8par.hxx
+++ b/sw/source/filter/ww8/ww8par.hxx
@@ -113,7 +113,7 @@ namespace com{namespace sun {namespace star{
 namespace lang{class XMultiServiceFactory;}
 }}}
 
-// defines nur fuer die WW8-variable der INI-Datei
+// defines only for the WW8-variable of the INI file
 #define WW8FL_NO_STYLES  2
 #define WW8FL_NO_GRAF 0x80
 
@@ -121,10 +121,10 @@ namespace com{namespace sun {namespace star{
 #define WW8FL_NO_IMPLPASP0x4000  // no implicit para space
 #define WW8FL_NO_GRAFLAYER   0x8000
 
-// Zusatz-Filter-Flags, gueltig ab Winword 8
+// Add-on-filter-flags, valid from Winword 8 on
 #define WW8FL_NO_FLY_FOR_TXBX 1
 
-//Listen-Manager (ab Ver8)
+//List-Manager (from Ver8 on)
 
 struct WW8LFOInfo;
 
@@ -162,7 +162,7 @@ private:
 const WW8FibrFib;
 SvStreamrSt;
 std::vectorWW8LSTInfo*  maLSTInfos;
-boost::ptr_vectorWW8LFOInfo  pLFOInfos;// D. aus PLF LFO, sortiert genau 
wie im WW8 Stream
+boost::ptr_vectorWW8LFOInfo  pLFOInfos;// D. from PLF LFO, sorted 
exactly like in the WW8 Stream
 sal_uInt16   nUniqueList; // current number for creating unique list 
names
 sal_uInt8* GrpprlHasSprm(sal_uInt16 nId, sal_uInt8 rSprms, sal_uInt8 
nLen);
 WW8LSTInfo* GetLSTByListId(sal_uInt32  nIdLst ) const;
@@ -172,9 +172,9 @@ private:
 bool bSetStartNo, std::dequebool rNotReallyThere, sal_uInt16 nLevel,
 ww::bytes rParaSprms);
 
-// Zeichenattribute aus GrpprlChpx
+// character attributes from GrpprlChpx
 typedef SfxItemSet* WW8aISet[nMaxLevel];
-// Zeichen Style Pointer
+// character style pointer
 typedef SwCharFormat* WW8aCFormat[nMaxLevel];
 
 void AdjustLVL(sal_uInt8 nLevel, SwNumRule rNumRule, WW8aISet 
rListItemSet,
@@ -187,20 +187,19 @@ private:
 };
 
 struct WW8FlyPara
-{   // WinWord-Attribute
-// Achtung: *Nicht* umsortieren, da Teile mit
-// memcmp verglichen werden
+{   // WinWord-attributes
+// Attention: *DO NOT* reorder, since parts will be
+// compared using memcmp
 bool bVer67;
-sal_Int16 nSp26, nSp27; // rohe Position
-sal_Int16 nSp45, nSp28; // Breite / Hoehe
-sal_Int16 nLeMgn, nRiMgn, nUpMgn, nLoMgn;   // Raender
-sal_uInt8 nSp29; // rohe Bindung + Alignment
+sal_Int16 nSp26, nSp27; // raw position
+sal_Int16 nSp45, nSp28; // width / height
+sal_Int16 nLeMgn, nRiMgn, nUpMgn, nLoMgn;   // borders
+sal_uInt8 nSp29; // raw binding + alignment
 sal_uInt8 nSp37; // Wrap-Mode ( 1 / 2; 0 = no Apo ? )
-WW8_BRCVer9_5 brc;  // Umrandung Top, Left, Bottom, Right, Between
-bool bBorderLines;  // Umrandungslinien
-bool bGrafApo;  // true: Dieser Rahmen dient allein dazu, die
-// enthaltene Grafik anders als zeichengebunden
-// zu positionieren
+WW8_BRCVer9_5 brc;  // borders Top, Left, Bottom, Right, Between
+bool bBorderLines;  // border lines
+bool bGrafApo;  // true: this frame is only used to position
+// the contained graphics *not* as a character
 bool mbVertSet; // true if vertical positioning has been set
 
 WW8FlyPara(bool bIsVer67, const WW8FlyPara* pSrc = 0);
@@ -217,9 +216,9 @@ class SwWW8StyInf
 OUStringsWWStyleName;
 sal_uInt16  nWWStyleId;
 public:
-rtl_TextEncoding eLTRFontSrcCharSet;// rtl_TextEncoding fuer den Font
-rtl_TextEncoding eRTLFontSrcCharSet;// rtl_TextEncoding fuer den Font
-rtl_TextEncoding eCJKFontSrcCharSet;// rtl_TextEncoding fuer den Font
+rtl_TextEncoding eLTRFontSrcCharSet;// rtl_TextEncoding for the font
+rtl_TextEncoding eRTLFontSrcCharSet;// rtl_TextEncoding for the font
+rtl_TextEncoding eCJKFontSrcCharSet;// rtl_TextEncoding for the font
 SwFormat*  pFormat;
 WW8FlyPara* pWWFly;
 SwNumRule*  pOutlineNumrule;
@@ -237,14 +236,14 @@ public:
 // 9: body text
 sal_uInt8 mnWW8OutlineLevel;
 
-sal_uInt16  n81Flags;   // Fuer Bold, Italic, ...
-sal_uInt16  n81BiDiFlags;   // Fuer Bold, Italic, ...
+sal_uInt16  n81Flags

[Libreoffice-commits] core.git: sw/source

2015-08-07 Thread Thomas Klausner
 sw/source/filter/ww8/wrtww8.hxx |   43 +++-
 1 file changed, 21 insertions(+), 22 deletions(-)

New commits:
commit cf27d96fa3bffe603941f3e11e871b3202a3ba96
Author: Thomas Klausner w...@netbsd.org
Date:   Fri Aug 7 18:54:33 2015 +0200

Translate remaining German comments to English.

XXX: one sentence sounds incorrect, I have added a TODO marker so someone
can check it.

Change-Id: I5bd5a01b64ad0f0234465ca9347b4b842e6d0172

diff --git a/sw/source/filter/ww8/wrtww8.hxx b/sw/source/filter/ww8/wrtww8.hxx
index 7e0d897..917b5f8 100644
--- a/sw/source/filter/ww8/wrtww8.hxx
+++ b/sw/source/filter/ww8/wrtww8.hxx
@@ -43,7 +43,7 @@
 #include vcl/graph.hxx
 class SvxBrushItem;
 
-// einige Forward Deklarationen
+// some forward declarations
 class SwWW8AttrIter;
 namespace msfilter
 {
@@ -106,7 +106,7 @@ class WW8_WrPlcPn;
 class WW8_WrPlcAnnotations;
 class MSWordSections;
 class WW8_WrPlcTextBoxes;
-class WW8_WrPct;// Verwaltung
+class WW8_WrPct;// administration
 class WW8_WrtBookmarks;
 class WW8_WrtRedlineAuthor;
 class SvxMSExportOLEObjects;
@@ -122,7 +122,7 @@ class SvxBrushItem;
 
 #include WW8TableInfo.hxx
 
-#define GRF_MAGIC_1 0x12// 3 magic Bytes fuer PicLocFc-Attribute
+#define GRF_MAGIC_1 0x12// 3 magic bytes for PicLocFc attribute
 #define GRF_MAGIC_2 0x34
 #define GRF_MAGIC_3 0x56
 #define GRF_MAGIC_321 0x563412L
@@ -236,7 +236,7 @@ class WW8_WrPlcSepx : public MSWordSections
 ::std::vector ::boost::shared_ptrWW8_PdAttrDesc  m_SectionAttributes;
 // hack to prevent adding sections in endnotes
 bool m_bHeaderFooterWritten;
-WW8_WrPlc0* pTextPos;// Pos der einzelnen Header / Footer
+WW8_WrPlc0* pTextPos;// Position of the headers/footers
 
 WW8_WrPlcSepx( const WW8_WrPlcSepx ) SAL_DELETED_FUNCTION;
 WW8_WrPlcSepx operator=( const WW8_WrPlcSepx ) SAL_DELETED_FUNCTION;
@@ -437,8 +437,9 @@ struct MSWordSaveData
 bool bOldFlyFrmAttrs : 1;
 bool bOldStartTOX : 1;
 bool bOldInWriteTOX : 1;
-// bOutPageDesc muss nicht gesichert werden, da es nur nicht waehrend der
-// Ausgabe von Spezial-Texten veraendert wird.
+// bOutPageDesc does not have to be saved, since it is only not modified
+// when outputting special texts.
+/// TODO wiz 20150807: not modified - modified? (translated literally)
 };
 
 /// Base class for WW8Export and DocxExport
@@ -450,9 +451,9 @@ public:
 typedef std::vectorsal_uLong::const_iterator mycCFIter;
 OUString m_aMainStg;
 std::vectorconst SwTOXType* m_aTOXArr;
-const SfxItemSet* m_pISet;// fuer Doppel-Attribute
+const SfxItemSet* m_pISet;// for double attributes
 WW8_WrPct*  m_pPiece; // Pointer auf Piece-Table
-SwNumRuleTable* m_pUsedNumTable;  // alle used NumRules
+SwNumRuleTable* m_pUsedNumTable;  // all used NumRules
 const SwTextNode *m_pTopNodeOfHdFtPage; /// Top node of host page when in 
hd/ft
 std::map sal_uInt16, sal_uInt16  m_aRuleDuplicates; //map to Duplicated 
numrules
 std::stack sal_Int32  m_aCurrentCharPropStarts; /// To remember the 
position in a run.
@@ -466,8 +467,8 @@ public:
 
 sal_uInt16 m_nCharFormatStart;
 sal_uInt16 m_nFormatCollStart;
-sal_uInt16 m_nStyleBeforeFly; /// Style-Nummer des Nodes,
-///   in/an dem ein Fly verankert ist
+sal_uInt16 m_nStyleBeforeFly; /// style number of the node
+///   to which the Fly is connected
 sal_uInt16 m_nLastFormatId;  /// Style of last TextNode in normal 
range
 sal_uInt16 m_nUniqueList; /// current number for creating unique 
list names
 unsigned int m_nHdFtIndex;
@@ -502,9 +503,8 @@ public:
 const sw::Frame *m_pParentFrame; // If set we are exporting content inside
 // a frame, e.g. a graphic node
 
-Point* m_pFlyOffset;  // zur Justierung eines im Writer als
-RndStdIds m_eNewAnchorType;   // Zeichen gebundenen Flys, der im WW
-// Absatzgebunden wird.
+Point* m_pFlyOffset;  // for adjusting of character-bound Fly 
in the Writer,
+RndStdIds m_eNewAnchorType;   // that is paragraph-bound in the WW.
 
 WW8_WrPlcField* m_pFieldMain; // fields in MainText
 WW8_WrPlcField* m_pFieldHdFt; // fields in Header/Footer
@@ -527,7 +527,7 @@ public:
 
 SwEscherEx* m_pEscher;// escher export class
 // #i43447# - removed
-//SwTwips nFlyWidth, nFlyHeight;  // Fuer Anpassung Graphic
+//SwTwips nFlyWidth, nFlyHeight;  // for adaptation of graphics
 
 sal_uInt8 m_nTextTyp;
 
@@ -538,7 +538,7 @@ public:
 bool m_bOutPageDescs : 1; /// PageDescs (section properties) are 
being written
 bool m_bOutFirstPage : 1; // write Attrset of FirstPageDesc
 bool m_bOutTable : 1; // table is being

[Libreoffice-commits] core.git: 2 commits - sw/source

2015-08-07 Thread Thomas Klausner
 sw/source/filter/ww8/docxfootnotes.hxx |2 -
 sw/source/filter/ww8/ww8par2.hxx   |   42 -
 2 files changed, 22 insertions(+), 22 deletions(-)

New commits:
commit 4bc76a73f42dc37a1e9792d89f846f9a9280e668
Author: Thomas Klausner w...@netbsd.org
Date:   Fri Aug 7 21:55:19 2015 +0200

Translate remaining German comments to English.

Change-Id: Iad76b958db7eab849a1bfe18b486a30eacc276e3

diff --git a/sw/source/filter/ww8/ww8par2.hxx b/sw/source/filter/ww8/ww8par2.hxx
index 453dfb3..c5c3c90 100644
--- a/sw/source/filter/ww8/ww8par2.hxx
+++ b/sw/source/filter/ww8/ww8par2.hxx
@@ -47,27 +47,27 @@ struct WW8SwFlyPara
 {
 SwFlyFrameFormat* pFlyFormat;
 
-// 1. Teil: daraus abgeleitete Sw-Attribute
+// part 1: directly derived Sw attributes
 sal_Int16 nXPos, nYPos; // Position
-sal_Int16 nLeMgn, nRiMgn;   // Raender
-sal_Int16 nUpMgn, nLoMgn;   // Raender
-sal_Int16 nWidth, nHeight;  // Groesse
+sal_Int16 nLeMgn, nRiMgn;   // borders
+sal_Int16 nUpMgn, nLoMgn;   // borders
+sal_Int16 nWidth, nHeight;  // size
 sal_Int16 nNetWidth;
 
-SwFrmSize eHeightFix;   // Hoehe Fix oder Min
-RndStdIds eAnchor;  // Bindung
-short eHRel; // Seite oder Seitenrand
-short eVRel; // Seite oder Seitenrand
-sal_Int16 eVAlign;   // Oben, unten, mittig
-sal_Int16 eHAlign;   // links, rechts, mittig
-SwSurround eSurround;   // Wrap-Mode
+SwFrmSize eHeightFix;   // height fixed or min
+RndStdIds eAnchor;  // binding
+short eHRel; // page or page border
+short eVRel; // page or page border
+sal_Int16 eVAlign;   // up, down, centered
+sal_Int16 eHAlign;   // left, right, centered
+SwSurround eSurround;   // wrap mode
 
-sal_uInt8 nXBind, nYBind;// relativ zu was gebunden
+sal_uInt8 nXBind, nYBind;// bound relative to what
 
-// 2.Teil: sich waehrend des Einlesens ergebende AEnderungen
+// part 2: changes found during reading
 long nNewNetWidth;
-SwPosition* pMainTextPos;   // um nach Apo in Haupttext zurueckzukehren
-sal_uInt16 nLineSpace;  // LineSpace in tw fuer Graf-Apos
+SwPosition* pMainTextPos;   // to return to main text after apo
+sal_uInt16 nLineSpace;  // line space in tw for graf apos
 bool bAutoWidth;
 bool bToggelPos;
 
@@ -89,15 +89,15 @@ class WW8RStyle: public WW8Style
 {
 friend class SwWW8ImplReader;
 wwSprmParser maSprmParser;
-SwWW8ImplReader* pIo;   // Parser-Klasse
-SvStream* pStStrm;  // Input-File
+SwWW8ImplReader* pIo;   // parser class
+SvStream* pStStrm;  // input file
 
-SwNumRule* pStyRule;// Bullets und Aufzaehlungen in Styles
+SwNumRule* pStyRule;// bullets and enumerations in styles
 
-sal_uInt8* pParaSprms;   // alle ParaSprms des UPX falls UPX.Papx
-sal_uInt16 nSprmsLen;   // Laenge davon
+sal_uInt8* pParaSprms;   // all ParaSprms of the UPX if UPX.Papx
+sal_uInt16 nSprmsLen;   // its length
 
-sal_uInt8 nWwNumLevel;   // fuer Bullets und Aufzaehlungen in 
Styles
+sal_uInt8 nWwNumLevel;   // for bullets and enumerations in styles
 
 bool bTextColChanged;
 bool bFontChanged;  // For Simulating Default-Font
commit 2724773573c68f5f4d0176c12a1deda0475a66e9
Author: Thomas Klausner w...@netbsd.org
Date:   Fri Aug 7 21:54:47 2015 +0200

Fix typo in comment.

Change-Id: I4adabd4eedc6dd9156eb40476e2141dece1e448d

diff --git a/sw/source/filter/ww8/docxfootnotes.hxx 
b/sw/source/filter/ww8/docxfootnotes.hxx
index 7969738..281d842 100644
--- a/sw/source/filter/ww8/docxfootnotes.hxx
+++ b/sw/source/filter/ww8/docxfootnotes.hxx
@@ -30,7 +30,7 @@ typedef ::std::vector const SwFormatFootnote*  
FootnotesVector;
 
 /** Remember footnotes/endnotes so that we can dump them in one go.
 
-Also rememeber the last added footnote Id to be able to write it in the
+Also remember the last added footnote Id to be able to write it in the
 DocxAttributeOutput::EndRunProperties() method.
 */
 class FootnotesList {
___
Libreoffice-commits mailing list
libreoffice-comm...@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] core.git: sw/source

2015-08-06 Thread Thomas Klausner
 sw/source/ui/chrdlg/pardlg.cxx |3 +--
 1 file changed, 1 insertion(+), 2 deletions(-)

New commits:
commit a1438658ff8cf86618acf27e6a3522968163
Author: Thomas Klausner w...@netbsd.org
Date:   Thu Aug 6 22:10:58 2015 +0200

Translate a comment to English.

Change-Id: I3cc3973e3740009b543d9a841396182e76e16203

diff --git a/sw/source/ui/chrdlg/pardlg.cxx b/sw/source/ui/chrdlg/pardlg.cxx
index c9bd552..7c1fb0c 100644
--- a/sw/source/ui/chrdlg/pardlg.cxx
+++ b/sw/source/ui/chrdlg/pardlg.cxx
@@ -225,8 +225,7 @@ void SwParaDlg::PageCreated(sal_uInt16 nId, SfxTabPage 
rPage)
   if(!( nHtmlMode  HTMLMODE_ON ) ||
 nHtmlMode  HTMLMODE_SOME_STYLES)
 {
-// Seitenumbruch nur, wenn der Cursor im Body-Bereich und nicht in
-// einer Tabelle steht
+// pagebreak only when the cursor is in the body-area and not in a 
table
 const FrmTypeFlags eType = rSh.GetFrmType(0,true);
 if(!(FrmTypeFlags::BODY  eType) ||
 rSh.GetSelectionType()  nsSelectionType::SEL_TBL)
___
Libreoffice-commits mailing list
libreoffice-comm...@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] core.git: sw/source

2015-08-06 Thread Thomas Klausner
 sw/source/filter/ww8/ww8struc.hxx |   45 ++
 1 file changed, 22 insertions(+), 23 deletions(-)

New commits:
commit 54ae52e1cef40d888495b323583c22cff0da6a8d
Author: Thomas Klausner w...@netbsd.org
Date:   Thu Aug 6 22:08:46 2015 +0200

Translate comments to English.

Change-Id: Ic1c22a4840c09249e9a1e8cf0712ee942fd030b1

diff --git a/sw/source/filter/ww8/ww8struc.hxx 
b/sw/source/filter/ww8/ww8struc.hxx
index 8838536..307a5c1 100644
--- a/sw/source/filter/ww8/ww8struc.hxx
+++ b/sw/source/filter/ww8/ww8struc.hxx
@@ -175,8 +175,8 @@ struct WW8_STD
 sal_uInt16  cupx : 4;  // # of UPXs (and UPEs)
 sal_uInt16  istdNext : 12; // next style
 sal_uInt16  bchUpe;// offset to end of upx's, start of upe's
-// jetzt neu:
-// ab Ver8 gibts zwei Felder mehr:
+// new:
+// from Ver8 on there are two more fields:
   sal_uInt16fAutoRedef : 1;/* auto redefine style when appropriate */
   sal_uInt16fHidden : 1;   /* hidden from UI? */
   sal_uInt16: 14;  /* unused bits */
@@ -191,7 +191,7 @@ struct WW8_STD
 
 static_assert(sizeof (WW8_STD) == 10, this has to match the msword size);
 
-/** Basis zum Einlesen UND zum Arbeiten (wird jeweils unter schiedlich beerbt)
+/** base for reading AND working on (will have different subclasses */
 */
 struct WW8_FFN_BASE // Font Descriptor
 {
@@ -211,15 +211,15 @@ struct WW8_FFN_BASE // Font Descriptor
 
 static_assert(sizeof (WW8_FFN_BASE) == 6, this has to match the msword size);
 
-/** Hiermit arbeiten wir im Parser (und Dumper)
+/** This is what we use in the Parser (and Dumper)
 */
 struct WW8_FFN : public WW8_FFN_BASE
 {
 // ab Ver8 als Unicode
-OUString sFontname;// 0x6 bzw. 0x40 ab Ver8 zero terminated string that
+OUString sFontname;// 0x6 or 0x40 resp. from Ver8 on zero terminated 
string that
 // records name of font.
 // Maximal size of szFfn is 65 
characters.
-// Vorsicht: Dieses Array kann auch 
kleiner sein!!!
+// Attention: This array can be 
smaller!!!
 // Possibly followed by a second sz 
which records the
 // name of an alternate font to use if 
the first named
 // font does not exist on this system.
@@ -429,10 +429,9 @@ struct WW8_DOGRID
 short dxaGrid;  // width of each grid square
 short dyaGrid;  // height of each grid square
 
-/* a c h t u n g : es duerfen keine solchen Bitfelder ueber einen 
eingelesenes Byte-Array
-gelegt werden!!
-stattdessen ist ein aBits1 darueber zu legen, das 
mit  auszulesen ist
-GRUND: Compiler auf Intel und Sparc sortieren die Bits unterschiedlich
+/* attention: you must not put bit fields on top of such a byte array read 
from a file!
+   instead put an aBits1 on it and read it out with .
+   reason: compilers on Intel and Sparc sort the bits differently
 */
 
 short dyGridDisplay:7;  // the number of grid squares (in the y direction)
@@ -530,7 +529,7 @@ struct WW8_TBD
 //  *   int :2  C0  reserved
 };
 
-struct WW8_TCell// hiermit wird weitergearbeitet (entspricht weitestgehend 
dem Ver8-Format)
+struct WW8_TCell// this is the base for further work (corresponds mostly 
to the Ver8 format)
 {
 // The single-bit fields should ideally be bool, but probably need to keep
 // them as sal_uInt8 to make them combine with the following two-bit
@@ -546,7 +545,7 @@ struct WW8_TCell// hiermit wird weitergearbeitet 
(entspricht weitestgehend d
 //  0 top
 //  1 center
 //  2 bottom
-sal_uInt16 fUnused  : 7;// reserved - nicht loeschen: macht das 
sal_uInt16 voll !!
+sal_uInt16 fUnused  : 7;// reserved - do not remove, fills up the 
sal_uInt16!
 
 WW8_BRCVer9 rgbrc[4];   // border codes
 //notational convenience for referring to brcTop, brcLeft, etc fields.
@@ -557,7 +556,7 @@ struct WW8_TCell// hiermit wird weitergearbeitet 
(entspricht weitestgehend d
 };
 // cbTC (count of bytes of a TC) is 18(decimal), 12(hex).
 
-struct WW8_TCellVer6// wird aus der Datei gelesen
+struct WW8_TCellVer6// read from file
 {
 sal_uInt8  aBits1Ver6;
 sal_uInt8  aBits2Ver6;
@@ -573,22 +572,22 @@ struct WW8_TCellVer6// wird aus der Datei gelesen
 };
 // cbTC (count of bytes of a TC) is 10(decimal), A(hex).
 
-struct WW8_TCellVer8// wird aus der Datei gelesen
+struct WW8_TCellVer8// read from file
 {
-SVBT16 aBits1Ver8;  // Dokumentation siehe oben unter WW8_TCell
+SVBT16 aBits1Ver8

[Libreoffice-commits] core.git: sw/source

2015-08-06 Thread Thomas Klausner
 sw/source/filter/ww8/ww8struc.hxx |1 -
 1 file changed, 1 deletion(-)

New commits:
commit 9f2beba81a0b70d1624cbb431fbb7563d6ef6b5b
Author: Thomas Klausner w...@netbsd.org
Date:   Thu Aug 6 22:14:07 2015 +0200

Fix comment.

Change-Id: I0f18205f63c6bd5f9375cf3328b72ba5ef84cbde

diff --git a/sw/source/filter/ww8/ww8struc.hxx 
b/sw/source/filter/ww8/ww8struc.hxx
index 307a5c1..43e1507 100644
--- a/sw/source/filter/ww8/ww8struc.hxx
+++ b/sw/source/filter/ww8/ww8struc.hxx
@@ -192,7 +192,6 @@ struct WW8_STD
 static_assert(sizeof (WW8_STD) == 10, this has to match the msword size);
 
 /** base for reading AND working on (will have different subclasses */
-*/
 struct WW8_FFN_BASE // Font Descriptor
 {
 // ab Ver6
___
Libreoffice-commits mailing list
libreoffice-comm...@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] core.git: .git-hooks/post-merge

2015-02-13 Thread Thomas Klausner
 .git-hooks/post-merge |2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

New commits:
commit f4f064da1aec45bb17d01cef59577191923c8ae4
Author: Thomas Klausner w...@netbsd.org
Date:   Fri Feb 13 16:40:36 2015 +0100

git-hooks: post-merge script does not need /bin/bash

Just use /bin/sh, which exists on more systems.

Change-Id: I5e5453b89841510473414a4c339b647b4f95ae7b

diff --git a/.git-hooks/post-merge b/.git-hooks/post-merge
index 25e62ed..b1be512 100755
--- a/.git-hooks/post-merge
+++ b/.git-hooks/post-merge
@@ -1,4 +1,4 @@
-#!/bin/bash
+#!/bin/sh
 
 # Do not warn if there were no real merge
 git rev-parse -q --verify HEAD^2 /dev/null || exit
___
Libreoffice-commits mailing list
libreoffice-comm...@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


Patch for compilation against boost-1.56.0

2014-08-28 Thread Thomas Klausner
Hi!

Jörg Sonnenberger made a patch fixing the compilation of
libreoffice-4.2.5.2 against boost-1.56.0. I've applied the patches to
git head (only one patch needed slight modifications). The result is
attached.

Usually, I would just push this, but since libreoffice distributes
matching boost versions for libreoffice releases, I'll let someone who
knows how this works in detail take over.

Please integrate this.

Thanks,
 Thomas

(please cc me, not currently subscribed to the mailing list)
From 6a2ef051cfdd0b4e61bd083a7f1965a69e5bd534 Mon Sep 17 00:00:00 2001
From: =?UTF-8?q?J=C3=B6rg=20Sonnenberger?= jo...@netbsd.org
Date: Thu, 28 Aug 2014 12:18:43 +0200
Subject: [PATCH] Fix build with boost-1.56.0.

Change-Id: I61686bf61ff1e0561c385492c563e4495456ca47
Signed-off-by: Thomas Klausner w...@netbsd.org
---
 canvas/source/cairo/cairo_spritecanvashelper.cxx| 3 ++-
 canvas/source/vcl/spritecanvashelper.cxx| 4 ++--
 dbaccess/source/ui/tabledesign/TableController.cxx  | 3 ++-
 oox/source/drawingml/table/tablecell.cxx| 4 ++--
 reportdesign/source/core/api/ReportDefinition.cxx   | 3 ++-
 slideshow/source/engine/activities/activitybase.hxx | 2 +-
 slideshow/source/engine/rehearsetimingsactivity.cxx | 3 ++-
 slideshow/source/engine/shapes/appletshape.cxx  | 6 --
 slideshow/source/engine/shapes/drawshape.cxx| 4 ++--
 slideshow/source/engine/shapes/mediashape.cxx   | 3 ++-
 slideshow/source/engine/unoviewcontainer.cxx| 3 ++-
 11 files changed, 23 insertions(+), 15 deletions(-)

diff --git a/canvas/source/cairo/cairo_spritecanvashelper.cxx 
b/canvas/source/cairo/cairo_spritecanvashelper.cxx
index eb33f8f..741dbb3 100644
--- a/canvas/source/cairo/cairo_spritecanvashelper.cxx
+++ b/canvas/source/cairo/cairo_spritecanvashelper.cxx
@@ -402,11 +402,12 @@ namespace cairocanvas
 ::basegfx::computeSetDifference( aUncoveredAreas,
  rUpdateArea.maTotalBounds,
  ::basegfx::B2DRange( rDestRect ) );
+SurfaceSharedPtr surface(mpOwningSpriteCanvas-getBufferSurface());
 ::std::for_each( aUncoveredAreas.begin(),
  aUncoveredAreas.end(),
  ::boost::bind( repaintBackground,
 boost::cref(pCompositingCairo),
-
boost::cref(mpOwningSpriteCanvas-getBufferSurface()),
+boost::cref(surface),
 _1 ) );
 
 cairo_rectangle( pWindowCairo.get(), 0, 0, rSize.getX(), rSize.getY() 
);
diff --git a/canvas/source/vcl/spritecanvashelper.cxx 
b/canvas/source/vcl/spritecanvashelper.cxx
index 13ae629..e2ded77 100644
--- a/canvas/source/vcl/spritecanvashelper.cxx
+++ b/canvas/source/vcl/spritecanvashelper.cxx
@@ -573,12 +573,12 @@ namespace vclcanvas
 
 // repaint all affected sprites on top of background into
 // VDev.
+::basegfx::B2DPoint outPos( 
::vcl::unotools::b2DPointFromPoint(aOutputPosition) );
 ::std::for_each( rSortedUpdateSprites.begin(),
  rSortedUpdateSprites.end(),
  ::boost::bind( spriteRedrawStub2,
 ::boost::ref( maVDev.get() ),
-::boost::cref(
-
::vcl::unotools::b2DPointFromPoint(aOutputPosition)),
+::boost::cref( outPos ),
 _1 ) );
 
 // flush to screen
diff --git a/dbaccess/source/ui/tabledesign/TableController.cxx 
b/dbaccess/source/ui/tabledesign/TableController.cxx
index d51d1bc..14f24e6 100644
--- a/dbaccess/source/ui/tabledesign/TableController.cxx
+++ b/dbaccess/source/ui/tabledesign/TableController.cxx
@@ -1396,7 +1396,8 @@ void OTableController::assignTable()
 setEditable( xMeta.is()  !xMeta-isReadOnly()  
(isAlterAllowed() || isDropAllowed() || isAddAllowed()) );
 if(!isEditable())
 {
-
::std::for_each(m_vRowList.begin(),m_vRowList.end(),boost::bind( 
OTableRow::SetReadOnly, _1, boost::cref( sal_True )));
+sal_Bool t( sal_True );
+
::std::for_each(m_vRowList.begin(),m_vRowList.end(),boost::bind( 
OTableRow::SetReadOnly, _1, boost::cref( t )));
 }
 m_bNew = false;
 // be notified when the table is in disposing
diff --git a/oox/source/drawingml/table/tablecell.cxx 
b/oox/source/drawingml/table/tablecell.cxx
index e91f5b8..033434a 100644
--- a/oox/source/drawingml/table/tablecell.cxx
+++ b/oox/source/drawingml/table/tablecell.cxx
@@ -117,9 +117,9 @@ void applyTableStylePart( oox::drawingml::FillProperties 
rFillProperties,
 if (rTableStylePart.getTextColor().isUsed

[Libreoffice-commits] core.git: configure.ac

2013-09-24 Thread Thomas Klausner
 configure.ac |   12 ++--
 1 file changed, 6 insertions(+), 6 deletions(-)

New commits:
commit 937cc1b38f75329c96bb4d4f8c728094ab16f1ec
Author: Thomas Klausner w...@netbsd.org
Date:   Tue Sep 24 14:57:36 2013 +0200

Use portable '=' comparison operator for test(1).

'==' only supported by bash, not even GNU coreutils.

Signed-off-by: Thomas Klausner w...@netbsd.org

diff --git a/configure.ac b/configure.ac
index 880732e..534ed40 100644
--- a/configure.ac
+++ b/configure.ac
@@ -2238,7 +2238,7 @@ else
 fi
 fi
 AC_MSG_RESULT($STRIP_COMPONENTS)
-if test x$STRIP_COMPONENTS == xunsupported; then
+if test x$STRIP_COMPONENTS = xunsupported; then
 AC_MSG_ERROR([you need a tar that is able to strip components.])
 fi
 AC_SUBST(STRIP_COMPONENTS)
@@ -3463,7 +3463,7 @@ if test $_os = WINNT; then
 
 MSPDB_PATH=
 
-if test $BITNESS_OVERRIDE == ; then
+if test $BITNESS_OVERRIDE = ; then
 MSPDB_PATH=$VC_PRODUCT_DIR/../Common7/IDE
 else
 MSPDB_PATH=$VC_PRODUCT_DIR/bin/amd64
@@ -3628,7 +3628,7 @@ AC_SUBST(SHOWINCLUDES_PREFIX)
 #
 # dbghelp.dll
 #
-if test $_os == WINNT; then
+if test $_os = WINNT; then
 BUILD_TYPE=$BUILD_TYPE DBGHELP
 fi
 
@@ -9065,7 +9065,7 @@ dnl 
===
 dnl Check for NPAPI interface to plug LibreOffice into browser windows
 dnl ===
 AC_MSG_CHECKING([whether to plug LibreOffice into browser windows])
-if test $_os == WINNT -o $_os != Android -a $_os != Darwin -a $_os != 
iOS -a \
+if test $_os = WINNT -o $_os != Android -a $_os != Darwin -a $_os != 
iOS -a \
 $enable_headless != yes -a $enable_gtk != no
 then
 AC_MSG_RESULT([yes])
@@ -12468,10 +12468,10 @@ if test $enable_mpl_subset = yes; then
 *) : ;;
 esac
 done
-if test $enable_opengl != no -o x$ENABLE_OPENGL == xTRUE; then
+if test $enable_opengl != no -o x$ENABLE_OPENGL = xTRUE; then
 AC_MSG_ERROR([need to --disable-opengl - GL transitions support.])
 fi
-if test $enable_lpsolve != no -o x$ENABLE_LPSOLVE == xTRUE; then
+if test $enable_lpsolve != no -o x$ENABLE_LPSOLVE = xTRUE; then
 AC_MSG_ERROR([need to --disable-lpsolve - calc linear programming 
solver.])
 fi
 
___
Libreoffice-commits mailing list
libreoffice-comm...@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] core.git: qadevOOo/tests sfx2/source sw/source wizards/com

2013-07-30 Thread Thomas Klausner
 qadevOOo/tests/java/ifc/sdb/_XSingleSelectQueryAnalyzer.java |2 +-
 sfx2/source/dialog/basedlgs.cxx  |4 ++--
 sw/source/ui/app/appenv.cxx  |4 ++--
 sw/source/ui/inc/envimg.hxx  |6 +++---
 wizards/com/sun/star/wizards/common/SystemDialog.java|2 +-
 wizards/com/sun/star/wizards/web/ProcessStatusRenderer.py|4 ++--
 6 files changed, 11 insertions(+), 11 deletions(-)

New commits:
commit 0b59f6953a57e4785c9fc3e4da33ebd801946339
Author: Thomas Klausner w...@netbsd.org
Date:   Wed Jul 31 00:09:46 2013 +0200

Fix some typos.

Signed-off-by: Thomas Klausner w...@netbsd.org

diff --git a/qadevOOo/tests/java/ifc/sdb/_XSingleSelectQueryAnalyzer.java 
b/qadevOOo/tests/java/ifc/sdb/_XSingleSelectQueryAnalyzer.java
index 18f03be..f0ff547 100644
--- a/qadevOOo/tests/java/ifc/sdb/_XSingleSelectQueryAnalyzer.java
+++ b/qadevOOo/tests/java/ifc/sdb/_XSingleSelectQueryAnalyzer.java
@@ -55,7 +55,7 @@ public class _XSingleSelectQueryAnalyzer extends 
MultiMethodTest {
 private XSingleSelectQueryComposer xComposer = null;
 
 /**
- * Recieves the object relations:
+ * Receives the object relations:
 * ul
 *  licodeXSingleSelectQueryComposer xCompoer/code/li
 * /ul p
diff --git a/sfx2/source/dialog/basedlgs.cxx b/sfx2/source/dialog/basedlgs.cxx
index ff44f01..24cfb9e 100644
--- a/sfx2/source/dialog/basedlgs.cxx
+++ b/sfx2/source/dialog/basedlgs.cxx
@@ -803,7 +803,7 @@ void SfxSingleTabDialog::setTabPage(SfxTabPage* pTabPage,
 if (!sTitle.isEmpty())
 SetText(sTitle);
 
-// Dialog recieves the HelpId of TabPage if there is any
+// Dialog receives the HelpId of TabPage if there is any
 OString sHelpId(pImpl-m_pSfxPage-GetHelpId());
 if (!sHelpId.isEmpty())
 SetHelpId(sHelpId);
@@ -873,7 +873,7 @@ void SfxNoLayoutSingleTabDialog::SetTabPage( SfxTabPage* 
pTabPage,
 // Set TabPage text in the Dialog
 SetText( pImpl-m_pSfxPage-GetText() );
 
-// Dialog recieves the HelpId of TabPage
+// Dialog receives the HelpId of TabPage
 SetHelpId( pImpl-m_pSfxPage-GetHelpId() );
 SetUniqueId( pImpl-m_pSfxPage-GetUniqueId() );
 }
diff --git a/sw/source/ui/app/appenv.cxx b/sw/source/ui/app/appenv.cxx
index af2bda4..6d6eab0 100644
--- a/sw/source/ui/app/appenv.cxx
+++ b/sw/source/ui/app/appenv.cxx
@@ -164,7 +164,7 @@ void SwModule::InsertEnv( SfxRequest rReq )
 aTmp += OUString::number( ++nTitleNo );
 xDocSh-SetTitle( aTmp );
 
-// if applicable, copy the old Collections Sender and Reciever to
+// if applicable, copy the old Collections Sender and Receiver to
 // a new document
 if ( pOldSh )
 {
@@ -312,7 +312,7 @@ void SwModule::InsertEnv( SfxRequest rReq )
 pSh-StartAllAction();
 pSh-DoUndo(sal_False);
 
-// Again, copy the new collections Sender and Reciever to
+// Again, copy the new collections Sender and Receiver to
 // a new document
 if ( pOldSh )
 {
diff --git a/wizards/com/sun/star/wizards/common/SystemDialog.java 
b/wizards/com/sun/star/wizards/common/SystemDialog.java
index 58b9e52..575bd90 100644
--- a/wizards/com/sun/star/wizards/common/SystemDialog.java
+++ b/wizards/com/sun/star/wizards/common/SystemDialog.java
@@ -348,7 +348,7 @@ public class SystemDialog
 }
 
 /**
- * just like the other showMessageBox(...) method, but recieves a
+ * just like the other showMessageBox(...) method, but receives a
  * peer argument to use to create the message box.
  * @param xMSF
  * @param peer
diff --git a/wizards/com/sun/star/wizards/web/ProcessStatusRenderer.py 
b/wizards/com/sun/star/wizards/web/ProcessStatusRenderer.py
index f123785..722a1b6 100644
--- a/wizards/com/sun/star/wizards/web/ProcessStatusRenderer.py
+++ b/wizards/com/sun/star/wizards/web/ProcessStatusRenderer.py
@@ -20,8 +20,8

Re: [Libreoffice-qa] New Bugzilla Version Picker items – 2

2012-06-11 Thread Thomas Klausner
On Fri, Jun 08, 2012 at 03:45:11PM +0200, Petr Mladek wrote:
 1. About dialog:
 
 
 It has to be user friendly. Last release candidate is the final build,
 so we must not mention RC in the version. The current scheme is:
 
   + 3.X.Y alphaZ   - for alpha release
   + 3.X.Y betaZ- for beta releases
 + 3.X.Y.Z- for release candidates; the last one is final
 
 , where Y is the number of the bugfix release
...
 4. Ubuntu/Debian:
 -
 
   + 3.X.Y~alphaZ   - for alpha releases
   + 3.X.Y~betaZ- for beta releases
   + 3.X.Y.Z- for release candidates
 
 I really like this solution. It seems to have everything. We just need
 to make sure that the tilda '~' is handled correctly and does not break
 some tools.

Why is the ~ necessary? Just do
+ 3.X.YalphaZ   - for alpha releases
+ 3.X.YbetaZ- for beta releases
+ 3.X.Y.Z   - for release candidates

And to answer your question for pkgsrc: it knows about alpha, beta
and rc and sorts them correctly. If there's a tilde in there we'd
have the change the pkgsrc name of the package to one without a tilde.
 Thomas
___
LibreOffice mailing list
LibreOffice@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice


Re: LibreOffice / go-oo license ...

2012-03-16 Thread Thomas Klausner
As Michael requested:

All of my past  future contributions to LibreOffice may be
 licensed under the MPL/LGPLv3+ dual license, including the
 go-oo code.

If you want to use a different open source license, that's probably
fine with me as well, just drop me a line to confirm.

Enjoy :)
 Thomas
___
LibreOffice mailing list
LibreOffice@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice


[Libreoffice-commits] .: 2 commits - configure.in

2012-01-22 Thread Thomas Klausner
 configure.in |2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

New commits:
commit 7afa76599cf0c9256e2dc85709f8cb2f1ac76282
Merge: 1684f1c... 799f2de...
Author: Thomas Klausner w...@netbsd.org
Date:   Sun Jan 22 12:29:04 2012 +0100

Merge branch 'master' of ssh://git.freedesktop.org/git/libreoffice/core

commit 1684f1cb1a7ca155e613d3da4e2c168e9618e62a
Author: Thomas Klausner w...@netbsd.org
Date:   Sun Jan 22 12:28:08 2012 +0100

Use more portable `=' comparison operator instead of `=='.

diff --git a/configure.in b/configure.in
index 3be6798..84beec3 100644
--- a/configure.in
+++ b/configure.in
@@ -9696,7 +9696,7 @@ dnlthis should be unified into using only one 
version for both
 
 AC_MSG_CHECKING([whether to use the system libjpeg])
 
-if test $SYSTEM_JPEG == YES; then
+if test $SYSTEM_JPEG = YES; then
 SYSTEM_LIBJPEG=YES
 AC_MSG_RESULT([yes])
 else
___
Libreoffice-commits mailing list
Libreoffice-commits@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


Re: [Libreoffice] environ not found

2011-05-21 Thread Thomas Klausner
On Thu, May 19, 2011 at 04:29:34PM +0100, Michael Meeks wrote:
 
 On Wed, 2011-05-18 at 17:13 +0200, Thomas Klausner wrote:
  Does this ring a bell for anyone?
 ..
  cp -f batch.bat ../../../unxbsdx3.pro/bin/batch.bat
  Making:libosl_process.so
  ../../../unxbsdx3.pro/slo/osl_process.o: In function 
  `read_parent_environment(std::vectorstd::string, 
  rtl::Allocatorstd::string *)':
  osl_process.cxx:(.text+0x416): undefined reference to `environ'
  osl_process.cxx:(.text+0x4a0): undefined reference to `environ'
  dmake:  Error code 1, while making 
  '../../../unxbsdx3.pro/lib/libosl_process.so'
  Retrying /disk/2/archive/libreoffice/sal/qa/osl/process
 
  And nm on /usr/lib/crt0.o reports:
 
   Hmm; are we linking with crt0.o though ? :-) at least on Linux our C
 library exports that symbol:

That might be the issue...

 $ objdump -T /lib/libc.so.6 | grep environ
 0016ad60  w   DO .bss 0004  GLIBC_2.0   _environ
 0016ad60  w   DO .bss 0004  GLIBC_2.0   environ
 0016ad60 gDO .bss 0004  GLIBC_2.0   __environ
 
   Sounds like a normal, nasty portability problem ;-)
 
   Why is it a new one though ? what changed ?

I haven't built for quite some time now, and I see that there were
quite a few changes to that file this year already...
It seems like a linkage issue.

I have been told that it's probably caused by building a shared
library with -Wl,-z,defs. On NetBSD-current one can supposedly use
-Wl,--ignore-unresolved-symbol,environ to work around this issue.
 Thomas
___
LibreOffice mailing list
LibreOffice@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice


Re: [Libreoffice] environ not found

2011-05-21 Thread Thomas Klausner
On Sat, May 21, 2011 at 03:29:27PM +0200, Francois Tigeot wrote:
 NetBSD libc exports almost nothing in comparison:

It's in /usr/lib/crt0.o, which is linked into all executables AFAIK.

 There must be something else, possibly a change in the compiler toolchain.
 Thomas, your last succesful build was with NetBSD 5.1, wasn't it ?

No, I only run -current, so it was some 5.99.[234][0-9].
 Thomas
___
LibreOffice mailing list
LibreOffice@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice


[Libreoffice] quota header in file_volume.cxx unneeded?

2011-05-18 Thread Thomas Klausner
Hi!

When building git head on NetBSD, it fails due to the inclusion of
#include ufs/ufs/quota.h
in ure/sal/osl/unx/file_volume.cxx. (The header isn't standalone any
longer in NetBSD-current).

Removing the header inclusion makes the problem go away and me wonder
if this header is needed on any platform.
Currently it's:
#if defined(SOLARIS)
...
#include sys/fs/ufs_quota.h
...
#elif defined(LINUX)
...
#include sys/quota.h
...
#elif defined(NETBSD) || defined(FREEBSD) || defined(OPENBSD) || 
defined(DRAGONFLY)
...
#include ufs/ufs/quota.h
...
#elif defined(MACOSX)
...
#include ufs/ufs/quota.h
...
#endif

Please check if you need this header on your platform.
 Thomas
___
LibreOffice mailing list
LibreOffice@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice


[Libreoffice] environ not found

2011-05-18 Thread Thomas Klausner
Hi!

Does this ring a bell for anyone?

cp -f batch.bat ../../../unxbsdx3.pro/bin/batch.bat
Making:libosl_process.so
../../../unxbsdx3.pro/slo/osl_process.o: In function 
`read_parent_environment(std::vectorstd::string, rtl::Allocatorstd::string 
*)':
osl_process.cxx:(.text+0x416): undefined reference to `environ'
osl_process.cxx:(.text+0x4a0): undefined reference to `environ'
dmake:  Error code 1, while making '../../../unxbsdx3.pro/lib/libosl_process.so'
Retrying /disk/2/archive/libreoffice/sal/qa/osl/process

I checked and the visits the
extern char** environ;
line in that file, and environ(7) says
 extern char **environ;
 ...
 An array of strings called the environment is made available by execve(2)
 when a process begins.  By convention these strings have the form
 ``name=value''.

And nm on /usr/lib/crt0.o reports:
 r .LC0
0020 r .LC1
0048 r .LC2
 w _DYNAMIC
 U _GLOBAL_OFFSET_TABLE_
 T ___start
 D __progname
 B __ps_strings
0110 T __start
 U __syscall
 U _exit
 U _fini
 U _init
 U _libc_init
0110 T _start
 U atexit
0008 C environ
 U exit
 U main

Ideas?
 Thomas
___
LibreOffice mailing list
LibreOffice@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice


Re: [Libreoffice] segfault in libqa_unit.so test

2011-01-06 Thread Thomas Klausner
On Tue, Jan 04, 2011 at 03:01:53PM +, Caolán McNamara wrote:
 One horrific temporary hack to test a theory would be to call _exit to
 skip calling the massive dtor chain which OOo builds up. Though that's
 not a cure, just a temp hack, but maybe it'll help isolate this.

I'm confused why, but with this patch applied, I get failure much
earlier.

Module 'odk' delivered successfully. 3 files copied, 1 files unchanged

---
Oh dear - something failed during the build - sorry !
  For more help with debugging build errors, please see the section in:
http://wiki.documentfoundation.org/Development

  internal build errors:

ERROR: error 65280 occurred while making /disk/2/archive/libreoffice/tools/qa

 it seems that the error is inside 'tools', please re-run build
 inside this module to isolate the error and/or test your fix:
---

rm -Rf /disk/2/archive/libreoffice/tools/unxbsdx3.pro # optional module 'clean'
/bin/bash
cd /disk/2/archive/libreoffice
source ./NetBSDX86-64Env.Set.sh
cd tools
build

when the problem is isolated and fixed exit and re-run 'make' from the top-level


when I do that:


Making:test_tools.so
../unxbsdx3.pro/slo/test_reversemap.o: In function `(anonymous 
namespace)::Test::testEncoding(unsigned short)':
test_reversemap.cxx:(.text+0x3f0): undefined reference to 
`getBestMSEncodingByChar(unsigned short)'
dmake:  Error code 1, while making '../unxbsdx3.pro/lib/test_tools.so'
Forcing regeneration of dependency info

diff --git a/sw/source/ui/inc/envimg.hxx b/sw/source/ui/inc/envimg.hxx
index 1c072c7..c9902fc 100644
--- a/sw/source/ui/inc/envimg.hxx
+++ b/sw/source/ui/inc/envimg.hxx
@@ -42,11 +42,11 @@ class SW_DLLPUBLIC SwEnvItem : public SfxPoolItem
 {
 public:
 
-OUString   aAddrText;   // text for reciever
+OUString   aAddrText;   // text for receiver
 sal_BoolbSend;   // sender?
 OUString   aSendText;   // text for sender
-sal_Int32   lAddrFromLeft;   // left gap for reciever (twips)
-sal_Int32   lAddrFromTop;// upper gap for reciever (twips)
+sal_Int32   lAddrFromLeft;   // left gap for receiver (twips)
+sal_Int32   lAddrFromTop;// upper gap for receiver (twips)
 sal_Int32   lSendFromLeft;   // left gap for sender (twips)
 sal_Int32   lSendFromTop;// upper gap for sender (twips)
 sal_Int32   lWidth;  // envelope's width (twips)
--
- start unit test #1 on library
--
:  
LD_LIBRARY_PATH=${LD_LIBRARY_PATH+${LD_LIBRARY_PATH}:}/disk/2/archive/libreoffice/clone/libs-gui/tools/unxbsdx3.pro/lib:/disk/2/archive/libreoffice/solver/330/unxbsdx3.pro/lib
  /disk/2/archive/libreoffice/solver/330/unxbsdx3.pro/bin/cppunittester 
Usage: cppunittester shared-library-path
dmake:  Error code 1, while making 'test1'
Retrying /disk/2/archive/libreoffice/tools/qa

Making:all_qa.dpslo
Making:test_tools.so
../unxbsdx3.pro/slo/test_reversemap.o: In function `(anonymous 
namespace)::Test::testEncoding(unsigned short)':
test_reversemap.cxx:(.text+0x3f0): undefined reference to 
`getBestMSEncodingByChar(unsigned short)'
dmake:  Error code 1, while making '../unxbsdx3.pro/lib/test_tools.so'

---
Oh dear - something failed during the build - sorry !
  For more help with debugging build errors, please see the section in:
http://wiki.documentfoundation.org/Development

 it seems that the error is inside 'tools', please re-run build
 inside this module to isolate the error and/or test your fix:
---

rm -Rf /disk/2/archive/libreoffice/tools/unxbsdx3.pro # optional module 'clean'
/bin/bash
cd /disk/2/archive/libreoffice
source ./NetBSDX86-64Env.Set.sh
cd tools
build


How can the diff cause that?
 Thomas
___
LibreOffice mailing list
LibreOffice@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice


Re: [Libreoffice] segfault in libqa_unit.so test

2011-01-06 Thread Thomas Klausner
On Thu, Jan 06, 2011 at 10:18:38PM +, Caolán McNamara wrote:
 Bah, let me rethink that. I guess its very possible that _exit doesn't
 flush standard I/O on NetBSD which might indeed cause an empty
 generated .hxx. I've just pushed a fflush into that generator to help
 test the theory. Try a pull and build again of tools.

With a new pull and your patch applied, I get to:
No EPM: do no packaging at this stage

Multiprocessing build is finished
Maximal number of processes run: 1

Is that the end of the build? (Where did the nice graphics go? ;) )

Thank you! How do we continue with this?
 Thomas
___
LibreOffice mailing list
LibreOffice@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice


[Libreoffice] segfault in libqa_unit.so test

2010-12-16 Thread Thomas Klausner
Hi!

I've switched back to the internal odbc library, since the external
one gave me the BOOL errors.

Strangely, --with-system-odbc-headers=no gives me an error by the
configure script because it's not recognized, but it makes the
configure script switch to the internal headers. Sebastian, want to
take a look at that?

The build on NetBSD currently fails with:

Entering /disk/2/archive/libreoffice/sc/qa/unit

--
- start unit test #1 on library ../../unxbsdx3.pro/lib/libqa_unit.so
--
:  
LD_LIBRARY_PATH=${LD_LIBRARY_PATH+${LD_LIBRARY_PATH}:}/disk/2/archive/libreoffice/clone/calc/sc/unxbsdx3.pro/lib:/disk/2/archive/libreoffice/solver/330/unxbsdx3.pro/lib
  /disk/2/archive/libreoffice/solver/330/unxbsdx3.pro/bin/cppunittester 
../../unxbsdx3.pro/lib/libqa_unit.so -headless -invisible \

-env:UNO_SERVICES=file:///disk/2/archive/libreoffice/clone/calc/sc/qa/unit/../../unxbsdx3.pro/misc/qa_unit/services.rdb
 \

-env:UNO_TYPES=file:///disk/2/archive/libreoffice/clone/calc/sc/qa/unit/../../unxbsdx3.pro/misc/qa_unit/types.rdb
 
file:///disk/2/archive/libreoffice/clone/calc/sc/qa/unit/../../unxbsdx3.pro/misc/qa_unit/udkapi.rdb
 \

-env:OOO_BASE_DIR=file:///disk/2/archive/libreoffice/clone/calc/sc/qa/unit/../../unxbsdx3.pro/misc/qa_unit
 \

-env:BRAND_BASE_DIR=file:///disk/2/archive/libreoffice/clone/calc/sc/qa/unit/../../unxbsdx3.pro/misc/qa_unit
 \

-env:UNO_USER_PACKAGES_CACHE=file:///disk/2/archive/libreoffice/clone/calc/sc/qa/unit/../../unxbsdx3.pro/misc/qa_unit
OK (3)
/bin/bash: line 1: 21530 Segmentation fault  (core dumped) 
LD_LIBRARY_PATH=${LD_LIBRARY_PATH+${LD_LIBRARY_PATH}:}/disk/2/archive/libreoffice/clone/calc/sc/unxbsdx3.pro/lib:/disk/2/archive/libreoffice/solver/330/unxbsdx3.pro/lib
 /disk/2/archive/libreoffice/solver/330/unxbsdx3.pro/bin/cppunittester 
../../unxbsdx3.pro/lib/libqa_unit.so -headless -invisible 
-env:UNO_SERVICES=file:///disk/2/archive/libreoffice/clone/calc/sc/qa/unit/../../unxbsdx3.pro/misc/qa_unit/services.rdb
 
-env:UNO_TYPES=file:///disk/2/archive/libreoffice/clone/calc/sc/qa/unit/../../unxbsdx3.pro/misc/qa_unit/types.rdb
 
file:///disk/2/archive/libreoffice/clone/calc/sc/qa/unit/../../unxbsdx3.pro/misc/qa_unit/udkapi.rdb
 
-env:OOO_BASE_DIR=file:///disk/2/archive/libreoffice/clone/calc/sc/qa/unit/../../unxbsdx3.pro/misc/qa_unit
 
-env:BRAND_BASE_DIR=file:///disk/2/archive/libreoffice/clone/calc/sc/qa/unit/../../unxbsdx3.pro/misc/qa_unit
 -env:UNO_USER_PACKAGES_CACHE=file:///disk/2/archive/libreoffice/clone/cal
 c/sc/qa/unit/../../unxbsdx3.pro/misc/qa_unit
dmake:  Error code 139, while making 'test'
Forcing regeneration of dependency info

nothing to do here...
--
- start unit test #1 on library
--
:  
LD_LIBRARY_PATH=${LD_LIBRARY_PATH+${LD_LIBRARY_PATH}:}/disk/2/archive/libreoffice/clone/calc/sc/unxbsdx3.pro/lib:/disk/2/archive/libreoffice/solver/330/unxbsdx3.pro/lib
  /disk/2/archive/libreoffice/solver/330/unxbsdx3.pro/bin/cppunittester  
-headless -invisible \

-env:UNO_SERVICES=file:///disk/2/archive/libreoffice/clone/calc/sc/qa/unit/../../unxbsdx3.pro/misc/qa_unit/services.rdb
 \

-env:UNO_TYPES=file:///disk/2/archive/libreoffice/clone/calc/sc/qa/unit/../../unxbsdx3.pro/misc/qa_unit/types.rdb
 
file:///disk/2/archive/libreoffice/clone/calc/sc/qa/unit/../../unxbsdx3.pro/misc/qa_unit/udkapi.rdb
 \

-env:OOO_BASE_DIR=file:///disk/2/archive/libreoffice/clone/calc/sc/qa/unit/../../unxbsdx3.pro/misc/qa_unit
 \ 

-env:BRAND_BASE_DIR=file:///disk/2/archive/libreoffice/clone/calc/sc/qa/unit/../../unxbsdx3.pro/misc/qa_unit
 \

-env:UNO_USER_PACKAGES_CACHE=file:///disk/2/archive/libreoffice/clone/calc/sc/qa/unit/../../unxbsdx3.pro/misc/qa_unit
terminate called after throwing an instance of 
'CppUnit::DynamicLibraryManagerException'
  what():  Failed to load dynamic library: -headless

/bin/bash: line 1: 28544 Abort trap  (core dumped) LD_LIBRARY_PATH=$
{LD_LIBRARY_PATH+${LD_LIBRARY_PATH}:}/disk/2/archive/libreoffice/clone/calc/sc/unxbsdx3.pro/lib:/disk/2/archive/libreoffice/solver/330/unxbsdx3.pro/lib
 /disk/2/archive/libreoffice/solver/330/unxbsdx3.pro/bin/cppunittester 
-headless -invisible 
-env:UNO_SERVICES=file:///disk/2/archive/libreoffice/clone/calc/sc/qa/unit/../../unxbsdx3.pro/misc/qa_unit/services.rdb
 
-env:UNO_TYPES=file:///disk/2/archive/libreoffice/clone/calc/sc/qa/unit/../../unxbsdx3.pro/misc/qa_unit/types.rdb
 
file:///disk/2/archive/libreoffice/clone/calc/sc/qa/unit/../../unxbsdx3.pro/misc/qa_unit/udkapi.rdb
 
-env:OOO_BASE_DIR=file:///disk/2/archive/libreoffice/clone/calc/sc/qa/unit/../../unxbsdx3.pro/misc/qa_unit
 
-env:BRAND_BASE_DIR=file:///disk/2/archive/libreoffice/clone/calc/sc/qa/unit/../../unxbsdx3.pro/misc/qa_unit
 

Re: [Libreoffice] BOOL conflict

2010-12-08 Thread Thomas Klausner
On Wed, Dec 08, 2010 at 10:49:27AM +, Michael Meeks wrote:
   Urk; another reason not to use BOOL I guess :-)
 
   What does your iodbcunix.h include ? I guess we might need to do some
 hideous #define magic for the iodbcunix.h headers here: did you get a
 solution ?

Not yet.

   I might be tempted to do:
 
 #define BOOL IODBC_BOOL
 #include iodbcunix.h
 #undef BOOL

If I only knew where it's included.

   or somesuch, if this is the only conflict.

Is a general sal_Bool - Bool, sal_True - true, sal_False - false
replacement ok? Then we could remove that type...
 Thomas
___
LibreOffice mailing list
LibreOffice@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice


[Libreoffice] How to commit commit-hook?

2010-12-07 Thread Thomas Klausner
Hi!

.git/hooks/pre-commit uses /usr/bin/perl -w as shebang instead of
/usr/bin/env perl.  When I change it and try to commit, git tells me
the file is unknown. How can I change it?
 Thomas
___
LibreOffice mailing list
LibreOffice@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice


Re: [Libreoffice] How to commit commit-hook?

2010-12-07 Thread Thomas Klausner
On Tue, Dec 07, 2010 at 10:29:25AM +0100, Thomas Klausner wrote:
 .git/hooks/pre-commit uses /usr/bin/perl -w as shebang instead of
 /usr/bin/env perl.  When I change it and try to commit, git tells me
 the file is unknown. How can I change it?

Found it, it's in git-hooks. Doh :)
 Thomas
___
LibreOffice mailing list
LibreOffice@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice


Re: [Libreoffice] new bootstrap: quick stop

2010-12-07 Thread Thomas Klausner
On Sun, Dec 05, 2010 at 07:17:28PM -0600, Norbert Thiebaud wrote:
 On Sun, Dec 5, 2010 at 7:03 PM, Thomas Klausner w...@netbsd.org wrote:
  I found the simplest fix for it:
  diff --git a/Makefile.in b/Makefile.in
  index 9e05c70..4fbbf4a 100644
  --- a/Makefile.in
  +++ b/Makefile.in
  @@ -1,7 +1,7 @@
   # @configure_input@
   # FIXME: create 'install' and 'check' target
 
  -SHELL=/bin/sh
  +SHELL=/bin/bash
 
   all: dmake/dm...@exeext@ fetch
        �...@. ./*[Ee]nv.[Ss]et.sh  \
 
  Seems the problems are caused by some difference between /bin/sh
  (NetBSD's /bin/sh) and bash.
 
  Ok to push?
  (Or is SHELL=env bash or something like this preferred?)
 
 /usr/bin/env bash
 
 that is what we use for shebang

Ok, committed and pushed.
 Thomas
___
LibreOffice mailing list
LibreOffice@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice


Re: [Libreoffice] new bootstrap: quick stop

2010-12-03 Thread Thomas Klausner
On Fri, Dec 03, 2010 at 04:07:08PM +, Michael Meeks wrote:
 Hi Miklos,
 
 On Fri, 2010-12-03 at 16:04 +0100, Miklos Vajna wrote:
  Trivial fix for the bootstrap repo attached, does it look sane?
 
   Prolly better to get the download script to create that itself ? [ and
 AFAIR the BSD'ers don't like mkdir -p ;-) ]

mkdir -p is fine on NetBSD.

   But great that you identified the problem.

Well, that doesn't fix the dmake problem...
 Thomas
___
LibreOffice mailing list
LibreOffice@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice


Re: [Libreoffice] new bootstrap: quick stop

2010-12-03 Thread Thomas Klausner
On Fri, Dec 03, 2010 at 08:31:12PM +, Michael Meeks wrote:
   Hmm, do you have dmake/dmake

Yes.

 - and do you also have it in your
 solver/./bin directory ? (where bootstrap should copy it if it
 succeeds ...).

No, that's the only copy:
# find . -name dmake
./dmake
./dmake/dmake
#
 Thomas
___
LibreOffice mailing list
LibreOffice@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice


Re: [Libreoffice] [PATCH] use linux bridge code on all BSDs

2010-11-05 Thread Thomas Klausner
On Fri, Nov 05, 2010 at 09:01:09PM +0100, Robert Nagy wrote:
 wiz, does this work on NetBSD? It does on OpenBSD,
 so i would like to push it.

Sorry for the delay, but I was still building.

The patch improves the situation on NetBSD as well, so please push it.
 Thomas
___
LibreOffice mailing list
LibreOffice@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice


[Libreoffice] [PUSHED] Re: [PATCH] use linux bridge code on all BSDs

2010-11-05 Thread Thomas Klausner
Pushed, thanks!
___
LibreOffice mailing list
LibreOffice@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice


[Libreoffice] build failure in dbaccess/qa/complex/dbaccess

2010-11-01 Thread Thomas Klausner
Entering /build/libreoffice-3.2.99.2/dbaccess/qa/complex/dbaccess

Making:DbaComplexTests.dpj

/usr/pkg/java/openjdk7/bin/javac -source 1.5 -target 1.5 -classpath 
.:../../../unxbsdx3.pro/class:/usr/pkg/java/openjdk7/jre/lib/rt.jar:.:/build/libreoffice-3.2.99.2/solver/330/unxbsdx3.pro/bin/ridl.jar:/build/libreoffice-3.2.99.2/solver/330/unxbsdx3.pro/bin/unoil.jar:/build/libreoffice-3.2.99.2/solver/330/unxbsdx3.pro/bin/jurt.jar:/build/libreoffice-3.2.99.2/solver/330/unxbsdx3.pro/bin/juh.jar:/build/libreoffice-3.2.99.2/solver/330/unxbsdx3.pro/bin/java_uno.jar:/build/libreoffice-3.2.99.2/solver/330/unxbsdx3.pro/bin/OOoRunner.jar:/build/libreoffice-3.2.99.2/solver/330/unxbsdx3.pro/bin/ConnectivityTools.jar::/build/libreoffice-3.2.99.2/solver/330/unxbsdx3.pro/lib
 -d ../../../unxbsdx3.pro/class  @/tmp/mk09676h
./CopyTableWizard.java:182: type Optional does not take parameters
OptionalString auto = new OptionalString();
^
./CopyTableWizard.java:182: type Optional does not take parameters
OptionalString auto = new OptionalString();
^
Note: Some input files use unchecked or unsafe operations.
Note: Recompile with -Xlint:unchecked for details.
2 errors

I don't speak Java -- help please :)
 Thomas
___
LibreOffice mailing list
LibreOffice@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice


Re: [Libreoffice] build failure loading pythonloader.uno.so

2010-11-01 Thread Thomas Klausner
On Sun, Oct 24, 2010 at 12:56:39PM +0100, Caolán McNamara wrote:
 This sucks, looks like catch throw and catch catch don't work on NetBSD.
 Or maybe its too old a gdb or something. Maybe add a break main and
 reorganize the gdb script in the hope that it needs libstdc++ to be
 loaded before it'll work. i.e. something like the (untested) attached.

br main let it find the symbols.

 The registering step should be effectively dlopening the modules that it
 wants to register, running the component_writeInfo function and friends
 in order to record into a registry file which .sos implement/support
 what named services. So manual debugging like adding some printf around
 the dlopen/dlsym calls in sal can help find what is the last .so to be
 dlopened, and adding/debugging the component_writeInfo etc calls in
 that .so can see if they're getting called at all, and sort of narrow
 down where things are going wrong.

I added some debugging printfs around dlopen/dlsym in sal/, as
suggested, and found that it was just another instance of rpath
problems (finding pyuno) which I currently just work around -- I added
a workaround for that and could continue my build :)

Thanks for your explanations and suggestions!
 Thomas
___
LibreOffice mailing list
LibreOffice@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice


Re: [Libreoffice] build failure loading pythonloader.uno.so

2010-10-25 Thread Thomas Klausner
On Mon, Oct 25, 2010 at 12:55:22PM +0100, Michael Meeks wrote:
   In addition to the other sage advice; I would tend to recommend going
 depth-first, and coming back to breadth.
 
   ie. get the build working / running with --disable-python.
 
   And then come back and fix this :-) Python is not actually required for
 LibreOffice to install / run - though quite possibly we should make it
 required in future :-)
 
   Or did you already get it working without python ?

That's actually a motivating idea, because then I'd have something
building first and could improve it later :)
However, --disable-python is not supported by configure.

# ./build/libreoffice-3.2.99.2/configure --help | grep -i python
  --with-system-pythonUse python already on system

Is there a differently named option that does what we want here?
 Thomas
___
LibreOffice mailing list
LibreOffice@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice


Re: [Libreoffice] ucb/source/ucb compilation error

2010-10-22 Thread Thomas Klausner
On Thu, Oct 21, 2010 at 05:16:32PM +0200, Thomas Klausner wrote:
 I'll switch diagnose.h (locally) to give   for OSL_THIS_FUNC, as it
 currently seems to do for everyone else.

To close this thread: I've pushed this change.
 Thomas
___
LibreOffice mailing list
LibreOffice@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice


[Libreoffice] update on OSL_LOG_PREFIX macro issue

2010-10-21 Thread Thomas Klausner
Hi again,

I've patched the OSL_LOG_PREFIX macro (see diff in previous mail) but
now the compilation falls over in 

Entering /build/libreoffice-3.2.99.2/sfx2/source/doc

Compiling: sfx2/source/doc/objmisc.cxx
g++  -fmessage-length=0 -c -O1 -DENABLE_LAYOUT=0 -DENABLE_LAYOUT_EXPERIMENTAL=0 
 -I/usr/pkg/include/db4 -I/usr/pkg/include -I/usr/X11R7/include -DSYSTEM_LIBXML 
-I/usr/pkg/include/libxml2   -I. -I../../unxbsdx3.pro/inc/doc -I../inc 
-I../../inc/pch -I../../inc -I../../unx/inc -I../../unxbsdx3.pro/inc -I. 
-I/build/libreoffice-3.2.99.2/solver/330/unxbsdx3.pro/inc/stl 
-I/build/libreoffice-3.2.99.2/solver/330/unxbsdx3.pro/inc/external 
-I/build/libreoffice-3.2.99.2/solver/330/unxbsdx3.pro/inc 
-I/build/libreoffice-3.2.99.2/solenv/unxbsdx3/inc 
-I/build/libreoffice-3.2.99.2/solenv/inc 
-I/build/libreoffice-3.2.99.2/res 
-I/build/libreoffice-3.2.99.2/solver/330/unxbsdx3.pro/inc/stl 
-I/build/libreoffice-3.2.99.2/solenv/inc/Xp31 
-I/usr/pkg/java/openjdk7/include -I/usr/pkg/java/openjdk7/include/netbsd 
-I/usr/pkg/java/openjdk7/include/native_threads/include -I/usr/X11R7/include  
-I/build/libreoffice-3.2.99.2/solver/330/unxbsdx3.pro/inc/offuh -I. 
-I../../res
  -I. -pipe   -Wno-ctor-dtor-privacy -I/usr/pkg/include/db4 -I/usr/pkg/include 
-I/usr/X11R7/include  -fpic -DNETBSD -DUNX -DVCL -DGCC -DC341 -DX86_64 -DX86_64 
-pthread -D_PTHREADS -D_REENTRANT -DNEW_SOLAR -D_USE_NAMESPACE=1 
-DSTLPORT_VERSION=450 -D__DMAKE -DUNIX -DCPPU_ENV=gcc3 
-DGXX_INCLUDE_PATH=/usr/include/g++ -DSUPD=330 -DPRODUCT -DNDEBUG 
-DOSL_DEBUG_LEVEL=0 -DOPTIMIZE -DGSTREAMER -DCUI -DSOLAR_JAVA   
-DSFX2_DLLIMPLEMENTATION -DSHAREDLIB -D_DLL_   -fexceptions 
-fno-enforce-eh-specs -DEXCEPTIONS_ON  -o ../../unxbsdx3.pro/slo/objmisc.o 
/build/libreoffice-3.2.99.2/sfx2/source/doc/objmisc.cxx
/build/libreoffice-3.2.99.2/sfx2/source/doc/objmisc.cxx: In member function 
'void SfxObjectShell::ResetError()':
/build/libreoffice-3.2.99.2/sfx2/source/doc/objmisc.cxx:287: error: 
expected primary-expression before '(' token
/build/libreoffice-3.2.99.2/sfx2/source/doc/objmisc.cxx:287: error: 
expected `)' before string constant
/build/libreoffice-3.2.99.2/sfx2/source/doc/objmisc.cxx:287: error: 
expected primary-expression before ')' token
/build/libreoffice-3.2.99.2/sfx2/source/doc/objmisc.cxx:287: error: 
expected `)' before string constant
/build/libreoffice-3.2.99.2/sfx2/source/doc/objmisc.cxx:287: error: 
expected `)' before ';' token
/build/libreoffice-3.2.99.2/sfx2/source/doc/objmisc.cxx:287: error: 
expected `)' before ';' token

The line is
 AddLog( ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( OSL_LOG_PREFIX 
Resetting Error. ) ) );

I didn't find a way to make this work (adding commas and parentheses).

So, back to square one: I wonder why OSL_LOG_PREFIX is working for
anyone else -- I'm using gcc-4.1.3/amd64 after all, that's not such an
unusual combination, is it? :)

To what is it expanded for your compiler, and what compiler is it?

Thanks,
 Thomas
___
LibreOffice mailing list
LibreOffice@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice


Re: [Libreoffice] Quick Patch to Fix sfx2 compile error

2010-10-21 Thread Thomas Klausner
On Thu, Oct 21, 2010 at 07:36:51AM -0700, Joseph Powers wrote:
 Not sure why no one else noticed this...  com::sun::star:: was missing on two 
 entries

Pushed, thanks!
 Thomas
___
LibreOffice mailing list
LibreOffice@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice


[Libreoffice] BOOL redefinition problem

2010-10-21 Thread Thomas Klausner
Hi!

Entering 
/disk/2/archive/libreoffice/build/libreoffice-3.2.99.2/connectivity/source/drivers/adabas

Compiling: connectivity/unxbsdx3.pro/misc/adabas_dflt_version.c
Compiling: connectivity/source/drivers/adabas/BDriver.cxx
/usr/pkg/include/iodbcunix.h:136: error: conflicting declaration 'typedef int 
BOOL'
/disk/2/archive/libreoffice/build/libreoffice-3.2.99.2/solver/330/unxbsdx3.pro/inc/tools/solar.h:57:
 error: 'BOOL' has a previous declaration as 'typedef sal_Bool BOOL'
dmake:  Error code 1, while making '../../../unxbsdx3.pro/slo/BDriver.obj'

Lines 135-137 of iodbcunix.h:
#if !defined(BOOL)  !defined(_OBJC_OBJC_H_)
typedef int BOOL;
#endif

Line 57 of solar.h is:
typedef sal_BoolBOOL;   /* typedef unsigned char   BOOL; */

Suggestions?
 Thomas
___
LibreOffice mailing list
LibreOffice@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice


Re: [Libreoffice] boost exceptions

2010-10-18 Thread Thomas Klausner
On Mon, Oct 18, 2010 at 11:14:25AM +0100, Caolán McNamara wrote:
 Why did you add -fexceptions to the arguments ?, I ask because there are
 places in LibreOffice where its explicitly enabled, and others where its
 explicitly disabled, so globally enabling it wouldn't be something
 typically tested before now. was there a prior error you were trying to
 avoid ? 

I got the same error, then I added the -fexceptions to avoid it, but
it didn't work. (The command line contains -fno-exceptions as well,
so probably that's the reason the added -fexceptions didn't change
anything).
 Thomas
___
LibreOffice mailing list
LibreOffice@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice


[Libreoffice] Changing patches

2010-10-18 Thread Thomas Klausner
Hi!

One of the issues I see is in SampleICC, where Vetters.cpp includes
errno.h on Solaris and sys/errno.h on all other non-Windows.

On NetBSD, it also needs to include errno.h to compile. I could add an
#if NetBSD to the Solaris case, but I don't think that sys/errno.h is
standardized and thus prefer to make it include errno.h on all
non-Windows platforms instead. What do you think?

The next question is how to change this, since the sys/errno.h include
gets added by one of the patches coming with LO. You probably already
have a tried-and-true workflow for this, what is it? :)

Thanks,
 Thomas
___
LibreOffice mailing list
LibreOffice@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice


Re: [Libreoffice] Changing patches

2010-10-18 Thread Thomas Klausner
On Mon, Oct 18, 2010 at 05:45:56PM +0100, Michael Meeks wrote:
   We have to edit the patch; icc is one of our 'external' components, so
 we have the pristine source archive, and then patch it with our internal
 patch as part of the build.
 
   So - we would need to alter the patch. That leads to some diffs of
 diffs problem, but ... hopefully there is some --with-system-icc variant
 that could be used, if indeed the patches don't change its behaviour in
 some unpleasant way.

I tried untarring the SampleIcc distfile and then just applying
clone/libs-extern/icc/SampleICC-1.3.2.patch on top of it using patch
-p2 inside the directory, as a first step so that I could change it
and generate a new patch. However, I got conflicts:

./Contrib/ICC_utils/Stubs.h.rej
./Contrib/ICC_utils/Vetters.cpp.rej
./IccProfLib/IccTagProfSeqId.cpp.rej

Am I missing a step?
 Thomas
___
LibreOffice mailing list
LibreOffice@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice


[Libreoffice] missing libicui18n

2010-10-17 Thread Thomas Klausner
Hi!

I hacked around a few build issues (I'm not yet sure how to handle the
rpath issues, ignore the -Wl,-R parts below), now the build fails for
me with:

Entering 
/disk/2/archive/libreoffice/build/libreoffice-3.2.99.2/i18npool/source/indexentry

Making:genindex_data
unx
g++ -Wl,-z,combreloc -Wl,-z,defs 
-Wl,-R/usr/local/lib/libreoffice/basis-link/program 
-Wl,-R/usr/local/lib/libreoffice@/basis-link/ure-link/lib 
-Wl,-R/archive/cvs/libreoffice/build/libreoffice-3.2.99.2/solver/330/unxbsdx3.pro/lib
 
-L/disk/2/archive/libreoffice/build/libreoffice-3.2.99.2/solver/330/unxbsdx3.pro/lib
 -Wl,-export-dynamic -L../../unxbsdx3.pro/lib -L../lib 
-L/disk/2/archive/libreoffice/build/libreoffice-3.2.99.2/solenv/unxbsdx3/lib 
-L/disk/2/archive/libreoffice/build/libreoffice-3.2.99.2/solver/330/unxbsdx3.pro/lib
 -L/disk/2/archive/libreoffice/build/libreoffice-3.2.99.2/solenv/unxbsdx3/lib 
-L/usr/pkg/java/openjdk7/lib -L/usr/pkg/java/openjdk7/jre/lib/amd64 
-L/usr/pkg/java/openjdk7/jre/lib/amd64/client 
-L/usr/pkg/java/openjdk7/jre/lib/amd64/native_threads -L/usr/X11R7/lib 
-R/usr/X11R7/lib -L/usr/pkg/lib/xulrunner-sdk/sdk/lib 
../../unxbsdx3.pro/obj/genindex_data.o \
-Wl,--whole-archive -lsalcpprt -Wl,--no-whole-archive -luno_sal -licui18n 
-licuuc -licudata -lm -lc -lgcc_s -lstdc++ -lpthread  -o 
../../unxbsdx3.pro/bin/genindex_data
ld: cannot find -licui18n
dmake:  Error code 1, while making '../../unxbsdx3.pro/bin/genindex_data'

And it's true, there is no libicui18n* anywhere. How should it have been built?

Thanks,
 Thomas
___
LibreOffice mailing list
LibreOffice@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice


Re: [Libreoffice] C{,PP}FLAGS ignored in sal

2010-10-15 Thread Thomas Klausner
On Fri, Oct 15, 2010 at 01:22:46PM +0200, David Tardon wrote:
 There is ENVCFLAGS for flags to add to $CC and ENVCFLAGSCXX for flags
 to add to $CXX .

That's a very good tip, thank you.

Why aren't the environment's CFLAGS and CPPFLAGS variables added
automatically?

Is there a similar LDFLAGS or LIBS variable?
 Thomas
___
LibreOffice mailing list
LibreOffice@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice


[Libreoffice] C{,PP}FLAGS ignored in sal

2010-10-13 Thread Thomas Klausner
Hi!

I'm building LO with:
./autogen.sh --with-git --with-system-libs --with-system-headers 
--with-system-zlib --with-system-jpeg --with-system-libxslt 
--with-system-libxml --with-system-mesa-headers --with-system-cairo 
--with-system-mozilla=mozilla --with-system-saxon --with-system-lucene 
--with-system-openssl CFLAGS=-I/usr/pkg/include -I/usr/X11R7/include 
CPPFLAGS=-I/usr/pkg/include LDFLAGS=-L/usr/pkg/lib -Wl,-R/usr/pkg/lib 
QTDIR=/usr/pkg/qt4 --with-jdk-home=/usr/pkg/java/openjdk7 --with-max-jobs=1 
--with-num-cpus=1 --disable-kde --disable-kde4 --with-system-mdds=no 
--with-system-altlinuxhyph=no --with-openldap --without-junit 
--with-system-mythes=no

The build fails with:
Compiling: sal/osl/all/debugbase.cxx
g++ -fmessage-length=0 -c -O1 -DENABLE_LAYOUT=0 -DENABLE_LAYOUT_EXPERIMENTAL=0  
 -D_FILE_OFFSET_BITS=no -I. -I../../unxbsdx3.pro/inc/oslall -I../inc 
-I../../inc/pch -I../../inc -I../../unx/inc -I../../unxbsdx3.pro/inc -I. 
-I/disk/2/archive/libreoffice/build/libreoffice-3.2.99.2/solver/330/unxbsdx3.pro/inc/stl
 
-I/disk/2/archive/libreoffice/build/libreoffice-3.2.99.2/solver/330/unxbsdx3.pro/inc/external
 
-I/disk/2/archive/libreoffice/build/libreoffice-3.2.99.2/solver/330/unxbsdx3.pro/inc
 -I/disk/2/archive/libreoffice/build/libreoffice-3.2.99.2/solenv/unxbsdx3/inc 
-I/disk/2/archive/libreoffice/build/libreoffice-3.2.99.2/solenv/inc 
-I/disk/2/archive/libreoffice/build/libreoffice-3.2.99.2/res 
-I/disk/2/archive/libreoffice/build/libreoffice-3.2.99.2/solver/330/unxbsdx3.pro/inc/stl
 -I/disk/2/archive/libreoffice/build/libreoffice-3.2.99.2/solenv/inc/Xp31 
-I/usr/pkg/java/openjdk7/include -I/usr/pkg/java/openjdk7/include/netbsd 
-I/usr/pkg/java/openjdk7/include/native_threads/include -I/
 usr/X11R7/include  
-I/disk/2/archive/libreoffice/build/libreoffice-3.2.99.2/solver/330/unxbsdx3.pro/inc/offuh
 -I. -I../../res -I. -pipe   -Wno-ctor-dtor-privacy-DNETBSD -DUNX -DVCL 
-DGCC -DC341 -DX86_64 -DX86_64 -pthread -D_PTHREADS -D_REENTRANT -DNEW_SOLAR 
-D_USE_NAMESPACE=1 -DSTLPORT_VERSION=450 -D__DMAKE -DUNIX -DCPPU_ENV=gcc3 
-DGXX_INCLUDE_PATH=/usr/include/g++ -DSUPD=330 -DPRODUCT -DNDEBUG 
-DOSL_DEBUG_LEVEL=0 -DOPTIMIZE -DGSTREAMER -DCUI -DSOLAR_JAVA -fexceptions 
-fno-enforce-eh-specs -DEXCEPTIONS_ON  -o ../../unxbsdx3.pro/obj/debugbase.o 
/disk/2/archive/libreoffice/build/libreoffice-3.2.99.2/sal/osl/all/debugbase.cxx
/disk/2/archive/libreoffice/build/libreoffice-3.2.99.2/sal/osl/all/debugbase.cxx:36:26:
 error: boost/bind.hpp: No such file or directory
/disk/2/archive/libreoffice/build/libreoffice-3.2.99.2/sal/osl/all/debugbase.cxx:
 In function 'bool osl_detail_ObjectRegistry_storeAddresses(const char*)':
/disk/2/archive/libreoffice/build/libreoffice-3.2.99.2/sal/osl/all/debugbase.cxx:104:
 error: 'boost' has not been declared
/disk/2/archive/libreoffice/build/libreoffice-3.2.99.2/sal/osl/all/debugbase.cxx:104:
 error: '_1' was not declared in this scope
dmake:  Error code 1, while making '../../unxbsdx3.pro/obj/debugbase.obj'

I don't see my CFLAGS nor CPPFLAGS, which would make it find boost, in
the gcc arguments.
How can I make them used in this part of the build?
 Thomas
___
LibreOffice mailing list
LibreOffice@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice


[Libreoffice] soltools build failure

2010-10-10 Thread Thomas Klausner
Hi!

Commencing main build
build -- version: 275224

Fetching dependencies for module l10n from solver... failed
Fetching dependencies for module testshl2 from solver... failed

=
Building module solenv
=

Entering /disk/2/archive/libreoffice/build/libreoffice-3.2.99.2/solenv

just for sideeffects...
solenv deliver
Module 'solenv' delivered successfully. 0 files copied, 2 files unchanged

=
Building module soltools
=

Entering 
/disk/2/archive/libreoffice/build/libreoffice-3.2.99.2/soltools/mkdepend

Compiling: soltools/mkdepend/cppsetup.c
gcc: ../unxbsdx3.pro/obj/cppsetup.o: No such file or directory
dmake:  Error code 1, while making '../unxbsdx3.pro/obj/cppsetup.obj'

1 module(s):
soltools
need(s) to be rebuilt

Reason(s):


Attention: if you fix the errors in above module(s) you may continue the build 
issuing the following command:

build --all:soltools

Any ideas where to look?
 Thomas
___
LibreOffice mailing list
LibreOffice@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice